package com.fs.web.controller.common;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


import com.fs.common.core.domain.R;
import com.fs.common.exception.file.OssException;
import com.fs.course.service.IHuaweiObsService;
import com.fs.course.service.IHuaweiVodService;
import com.fs.course.service.ITencentCloudCosService;
import com.fs.course.service.impl.HuaweiObsServiceImpl;
import com.fs.framework.config.ServerConfig;
import com.fs.his.domain.FsExportTask;
import com.fs.his.service.IFsExportTaskService;
import com.fs.system.oss.CloudStorageService;
import com.fs.system.oss.OSSFactory;

import com.fs.web.vo.WangUploadVO;

import com.huaweicloud.sdk.vod.v1.model.BaseInfo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import com.fs.common.config.FSConfig;
import com.fs.common.constant.Constants;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.utils.StringUtils;
import com.fs.common.utils.file.FileUploadUtils;
import com.fs.common.utils.file.FileUtils;

import java.io.File;
import java.io.IOException;
import java.util.*;
import java.util.concurrent.ConcurrentHashMap;

import static com.fs.course.service.impl.HuaweiObsServiceImpl.fileUrlMap;
import static com.fs.course.service.impl.HuaweiObsServiceImpl.uploadProgress;


/**
 * 通用请求处理
 *

 */
@RestController
public class CommonController
{


    private static final Logger log = LoggerFactory.getLogger(CommonController.class);

    @Autowired
    private ServerConfig serverConfig;

    @Autowired
    private ITencentCloudCosService tencentCloudCosService;
    @Autowired
    private IFsExportTaskService exportTaskService;
    @GetMapping(value = "common/getTask/{taskId}")
    public R getTask(@PathVariable("taskId") Long taskId)
    {
        FsExportTask task=exportTaskService.selectFsExportTaskByTaskId(taskId);
        return R.ok().put("data",task);
    }
    /**
     * 通用下载请求
     *
     * @param fileName 文件名称
     * @param delete 是否删除
     */
    @GetMapping("common/download")
    public void fileDownload(String fileName, Boolean delete, HttpServletResponse response, HttpServletRequest request)
    {
        try
        {
            if (!FileUtils.checkAllowDownload(fileName))
            {
                throw new Exception(StringUtils.format("文件名称({})非法，不允许下载。 ", fileName));
            }
            String realFileName = System.currentTimeMillis() + fileName.substring(fileName.indexOf("_") + 1);
            String filePath = FSConfig.getDownloadPath() + fileName;

            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            FileUtils.setAttachmentResponseHeader(response, realFileName);
            FileUtils.writeBytes(filePath, response.getOutputStream());
            if (delete)
            {
                FileUtils.deleteFile(filePath);
            }
        }
        catch (Exception e)
        {
            log.error("下载文件失败", e);
        }
    }

    /**
     * 通用上传请求
     */
    @PostMapping("/common/upload")
    public AjaxResult uploadFile(MultipartFile file) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = FSConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("fileName", fileName);
            ajax.put("url", url);
            return ajax;
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }
    }

    /**
     * 本地资源通用下载
     */
    @GetMapping("/common/download/resource")
    public void resourceDownload(String resource, HttpServletRequest request, HttpServletResponse response)
            throws Exception
    {
        try
        {
            if (!FileUtils.checkAllowDownload(resource))
            {
                throw new Exception(StringUtils.format("资源文件({})非法，不允许下载。 ", resource));
            }
            // 本地资源路径
            String localPath = FSConfig.getProfile();
            // 数据库资源地址
            String downloadPath = localPath + StringUtils.substringAfter(resource, Constants.RESOURCE_PREFIX);
            // 下载名称
            String downloadName = StringUtils.substringAfterLast(downloadPath, "/");
            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            FileUtils.setAttachmentResponseHeader(response, downloadName);
            FileUtils.writeBytes(downloadPath, response.getOutputStream());
        }
        catch (Exception e)
        {
            log.error("下载文件失败", e);
        }
    }

    @PostMapping("common/uploadOSS")
    public R uploadOSS(@RequestParam("file") MultipartFile file) throws Exception
    {
        if (file.isEmpty())
        {
            throw new OssException("上传文件不能为空");
        }
        // 上传文件
        String fileName = file.getOriginalFilename();
        String suffix = fileName.substring(fileName.lastIndexOf("."));
        CloudStorageService storage = OSSFactory.build();
        String url = storage.uploadSuffix(file.getBytes(), suffix);
        return R.ok().put("url",url);
    }
    @PostMapping("/common/uploadWang")
    public WangUploadVO uploadWang(@RequestParam(value = "fileName", required = false) MultipartFile file) throws Exception
    {
        WangUploadVO vo=new WangUploadVO();
        try
        {
            if (file.isEmpty())
            {
                throw new OssException("上传文件不能为空");
            }
            // 上传文件
            String fileName = file.getOriginalFilename();
            String suffix = fileName.substring(fileName.lastIndexOf("."));
            CloudStorageService storage = OSSFactory.build();
            String url = storage.uploadSuffix(file.getBytes(), suffix);
            vo.setErrno(0);
            List<WangUploadVO.WangUploadItem> items=new ArrayList<>();
            WangUploadVO.WangUploadItem item=new WangUploadVO.WangUploadItem();
            item.setUrl(url);
            items.add(item);
            vo.setData(items);
            return vo;
        }
        catch (Exception e)
        {
            vo.setErrno(-1);
            return vo;
        }
    }

    //获取腾讯云vod签名
//    @PostMapping("/common/getSignature")
//    public R getVodSignature() {
//        String SECRET_ID = "AKIDdAdvzoQpzuOo11mq2TntjKI5eqrhNp22";
//        String SECRET_KEY = "zmLgpzzcwAFNJ4dx2iDTVHgw3ELCrIVg";
//        VodSignatureUtil sign = new VodSignatureUtil();
//        // 设置 App 的云 API 密钥
//        sign.setSecretId(SECRET_ID);
//        sign.setSecretKey(SECRET_KEY);
//        sign.setCurrentTime(System.currentTimeMillis() / 1000);
//        sign.setRandom(new Random().nextInt(java.lang.Integer.MAX_VALUE));
//        sign.setSignValidDuration(3600 * 24 * 2); // 签名有效期：2天
//        try {
//            String signature = sign.getUploadSignature();
//            System.out.println("signature : " + signature);
//        return R.ok().put("data",signature);
//        } catch (Exception e) {
//            System.out.println("生成签名失败：" + e.getMessage());
//            e.printStackTrace();
//        }
//        return R.error("生成签名失败");
//    }




    @GetMapping("/common/getTmpSecretKey")
    public R getTmpSecretKey()
    {
        return tencentCloudCosService.getKeyAndCredentials();
    }




}
