package com.fs.common.utils;

import java.lang.management.ManagementFactory;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.*;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.Calendar;
import java.util.Date;
import org.apache.commons.lang3.time.DateFormatUtils;

/**
 * 时间工具类
 *

 */
public class DateUtils extends org.apache.commons.lang3.time.DateUtils
{
    public static String YYYY = "yyyy";

    public static String YYYY_MM = "yyyy-MM";

    public static String YYYY_MM_DD = "yyyy-MM-dd";

    public static String YYYYMMDDHHMMSS = "yyyyMMddHHmmss";

    public static String YYYY_MM_DD_HH_MM_SS = "yyyy-MM-dd HH:mm:ss";

    private static String[] parsePatterns = {
            "yyyy-MM-dd", "yyyy-MM-dd HH:mm:ss", "yyyy-MM-dd HH:mm", "yyyy-MM",
            "yyyy/MM/dd", "yyyy/MM/dd HH:mm:ss", "yyyy/MM/dd HH:mm", "yyyy/MM",
            "yyyy.MM.dd", "yyyy.MM.dd HH:mm:ss", "yyyy.MM.dd HH:mm", "yyyy.MM"};
    private static final DateTimeFormatter OUTPUT_FORMATTER = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

    /**
     * 获取当前Date型日期
     *
     * @return Date() 当前日期
     */
    public static Date getNowDate()
    {
        return new Date();
    }

    /**
     * 获取当前日期, 默认格式为yyyy-MM-dd
     *
     * @return String
     */
    public static String getDate()
    {
        return dateTimeNow(YYYY_MM_DD);
    }

    public static final String getTime()
    {
        return dateTimeNow(YYYY_MM_DD_HH_MM_SS);
    }

    public static final String dateTimeNow()
    {
        return dateTimeNow(YYYYMMDDHHMMSS);
    }

    public static final String dateTimeNow(final String format)
    {
        return parseDateToStr(format, new Date());
    }

    public static final String dateTime(final Date date)
    {
        return parseDateToStr(YYYY_MM_DD, date);
    }

    public static final String parseDateToStr(final String format, final Date date)
    {
        return new SimpleDateFormat(format).format(date);
    }

    public static final Date dateTime(final String format, final String ts)
    {
        try
        {
            return new SimpleDateFormat(format).parse(ts);
        }
        catch (ParseException e)
        {
            throw new RuntimeException(e);
        }
    }

    /**
     * 日期路径 即年/月/日 如2018/08/08
     */
    public static final String datePath()
    {
        Date now = new Date();
        return DateFormatUtils.format(now, "yyyy/MM/dd");
    }

    /**
     * 日期路径 即年/月/日 如20180808
     */
    public static final String dateTime()
    {
        Date now = new Date();
        return DateFormatUtils.format(now, "yyyyMMdd");
    }

    /**
     * 日期型字符串转化为日期 格式
     */
    public static Date parseDate(Object str)
    {
        if (str == null)
        {
            return null;
        }
        try
        {
            return parseDate(str.toString(), parsePatterns);
        }
        catch (ParseException e)
        {
            return null;
        }
    }

    /**
     * 获取服务器启动时间
     */
    public static Date getServerStartDate()
    {
        long time = ManagementFactory.getRuntimeMXBean().getStartTime();
        return new Date(time);
    }

    /**
     * 计算两个时间差
     */
    public static String getDatePoor(Date endDate, Date nowDate)
    {
        long nd = 1000 * 24 * 60 * 60;
        long nh = 1000 * 60 * 60;
        long nm = 1000 * 60;
        // long ns = 1000;
        // 获得两个时间的毫秒时间差异
        long diff = endDate.getTime() - nowDate.getTime();
        // 计算差多少天
        long day = diff / nd;
        // 计算差多少小时
        long hour = diff % nd / nh;
        // 计算差多少分钟
        long min = diff % nd % nh / nm;
        // 计算差多少秒//输出结果
        // long sec = diff % nd % nh % nm / ns;
        return day + "天" + hour + "小时" + min + "分钟";
    }
    public static int getAge(Date birthDay) {
        Calendar cal = Calendar.getInstance();
        //出生日期晚于当前时间，无法计算
        if (cal.before(birthDay)) {
            throw new IllegalArgumentException(
                    "The birthDay is before Now.It's unbelievable!");
        }
        //当前年份
        int yearNow = cal.get(Calendar.YEAR);
        //当前月份
        int monthNow = cal.get(Calendar.MONTH);
        //当前日期
        int dayOfMonthNow = cal.get(Calendar.DAY_OF_MONTH);
        cal.setTime(birthDay);
        int yearBirth = cal.get(Calendar.YEAR);
        int monthBirth = cal.get(Calendar.MONTH);
        int dayOfMonthBirth = cal.get(Calendar.DAY_OF_MONTH);
        //计算整岁数
        int age = yearNow - yearBirth;
        if (monthNow <= monthBirth) {
            if (monthNow == monthBirth) {
                if (dayOfMonthNow < dayOfMonthBirth) {
                    //当前日期在生日之前，年龄减一
                    age--;
                }
            } else {
                //当前月份在生日之前，年龄减一
                age--;

            }
        }
        return age;
    }
    /**
     * 计算给定日期与当前日期相差的天数 (基于日历日期)。
     * 例如：昨天 23:59 和 今天 00:01 相差 1 天。
     *
     * @param createTime 起始时间 (java.util.Date)
     * @return 相差的天数 (long)。如果 createTime 为 null，返回 0。
     *         如果 createTime 在当前时间之后，结果为负数。
     */
    public static long getDaysDifferenceFromNow(Date createTime) {
        if (createTime == null) {
            return 0; // 或者根据业务抛出异常或返回特定值
        }
        // 1. 将 java.util.Date 转换为 Instant (时间线上的一个点)
        Instant createInstant = createTime.toInstant();
        // 2. 获取当前时间的 Instant
        Instant nowInstant = Instant.now();
        // 3. 指定时区 (非常重要！否则会使用系统默认时区，可能导致不一致)
        //    建议使用一个明确的时区，例如服务器所在时区或业务标准时区
        ZoneId zoneId = ZoneId.systemDefault(); // 或者 ZoneId.of("Asia/Shanghai");
        // 4. 将 Instant 转换为 LocalDate (只包含年月日，忽略时分秒)
        LocalDate createDate = createInstant.atZone(zoneId).toLocalDate();
        LocalDate nowDate = nowInstant.atZone(zoneId).toLocalDate(); // 使用相同的时区
        // 5. 使用 ChronoUnit.DAYS.between 计算两个 LocalDate 之间的天数差
        long daysBetween = ChronoUnit.DAYS.between(createDate, nowDate);
        return daysBetween;
    }

    /**
     * 获取指定日期当天的开始时间字符串 (格式: yyyy-MM-dd 00:00:00)
     *
     * @param date 输入的 Date 对象
     * @return 当天开始时间的字符串表示，如果输入为 null 则返回 null
     */
    public static String getStartOfDayString(Date date) {
        // 使用 Objects.requireNonNull(date, "输入日期不能为 null"); 如果希望在输入为 null 时抛出异常
        if (date == null) {
            return null;
        }
        // 1. 将 Date 转换为更现代的 LocalDateTime (考虑时区)
        //    使用系统默认时区。如果需要特定时区，请替换 ZoneId.systemDefault()
        //    例如：ZoneId.of("Asia/Shanghai")
        LocalDateTime localDateTime = date.toInstant()
                .atZone(ZoneId.systemDefault())
                .toLocalDateTime();
        // 2. 获取该日期的开始时间 (00:00:00)
        LocalDateTime startOfDay = localDateTime.toLocalDate().atStartOfDay();
        // 3. 格式化为目标字符串
        return startOfDay.format(OUTPUT_FORMATTER);
    }
    /**
     * 获取指定日期当天的结束时间字符串 (格式: yyyy-MM-dd 23:59:59)
     *
     * @param date 输入的 Date 对象
     * @return 当天结束时间的字符串表示，如果输入为 null 则返回 null
     */
    public static String getEndOfDayString(Date date) {
        if (date == null) {
            return null;
        }
        // 1. 将 Date 转换为 LocalDateTime (考虑时区)
        LocalDateTime localDateTime = date.toInstant()
                .atZone(ZoneId.systemDefault())
                .toLocalDateTime();
        // 2. 获取该日期的 LocalDate 部分
        LocalDate localDate = localDateTime.toLocalDate();
        // 3. 创建当天的结束时间 (23:59:59)
        LocalDateTime endOfDay = LocalDateTime.of(localDate, LocalTime.of(23, 59, 59));
        // 注意: 如果需要的是一天的最后一纳秒 (23:59:59.999999999)，可以使用:
        // LocalDateTime endOfDay = LocalDateTime.of(localDate, LocalTime.MAX);
        // 但根据 "23:59:59" 的要求，明确指定秒更符合。
        // 4. 格式化为目标字符串
        return endOfDay.format(OUTPUT_FORMATTER);
    }


}
