package com.fs.framework.service;

import com.fs.company.domain.CompanyUser;
import com.fs.company.service.ICompanyMenuService;
import com.fs.company.service.ICompanyRoleService;
import com.fs.hospital.domain.HospitalUser;
import com.fs.hospital.service.IHospitalMenuService;
import com.fs.hospital.service.IHospitalRoleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.HashSet;
import java.util.Set;

/**
 * 用户权限处理
 *

 */
@Component
public class HospitalPermissionService
{
    @Autowired
    private IHospitalRoleService roleService;
    @Autowired
    private IHospitalMenuService menuService;

    /**
     * 获取角色数据权限
     *
     * @param user 用户信息
     * @return 角色权限信息
     */
    public Set<String> getRolePermission(HospitalUser user)
    {
        Set<String> roles = new HashSet<String>();
        // 管理员拥有所有权限
        if (user.isAdmin())
        {
            roles.add("admin");
        }
        else
        {
            roles.addAll(roleService.selectRolePermissionByUserId(user.getUserId()));
        }
        return roles;
    }

    /**
     * 获取菜单数据权限
     *
     * @param user 用户信息
     * @return 菜单权限信息
     */
    public Set<String> getMenuPermission(HospitalUser user)
    {
        Set<String> perms = new HashSet<String>();
        // 管理员拥有所有权限
        if (user.isAdmin())
        {
            perms.add("*:*:*");
        }
        else
        {
            perms.addAll(menuService.selectMenuPermsByUserId(user.getUserId()));
        }
        return perms;
    }
}
