package com.fs.hospital.controller.hospital;

import com.fs.common.constant.Constants;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.core.redis.RedisCache;
import com.fs.common.utils.ServletUtils;
import com.fs.company.domain.CompanyMenu;
import com.fs.company.domain.CompanyUser;
import com.fs.company.service.ICompanyMenuService;
import com.fs.framework.security.LoginBody;
import com.fs.framework.security.LoginUser;
import com.fs.framework.service.HospitalLoginService;
import com.fs.framework.service.HospitalPermissionService;
import com.fs.framework.service.TokenService;
import com.fs.hospital.domain.Hospital;
import com.fs.hospital.domain.HospitalMenu;
import com.fs.hospital.domain.HospitalUser;
import com.fs.hospital.service.IHospitalMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Set;

/**
 * 登录验证
 *

 */
@RestController
public class HospitalLoginController
{
    @Autowired
    private HospitalLoginService loginService;

    @Autowired
    private IHospitalMenuService menuService;

    @Autowired
    private HospitalPermissionService permissionService;

    @Autowired
    private TokenService tokenService;
    @Autowired
    private RedisCache redisCache;

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public AjaxResult login(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
                loginBody.getUuid());
        ajax.put(Constants.TOKEN, token);
        return ajax;
    }


    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public AjaxResult getInfo()
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        Hospital hospital = loginUser.getHospital();
        HospitalUser user = loginUser.getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        AjaxResult ajax = AjaxResult.success();
        ajax.put("user", user);
        ajax.put("hospital", hospital);
        ajax.put("roles", roles);
        ajax.put("permissions", permissions);


        return ajax;
    }

    /**
     * 获取路由信息
     *
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public AjaxResult getRouters()
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        // 用户信息
        HospitalUser user = loginUser.getUser();
        List<HospitalMenu> menus = menuService.selectMenuTreeByUserId(user.getUserId(), loginUser.getUser().isAdmin());

        return AjaxResult.success(menuService.buildMenus(menus));
    }

}

