package com.fs.app.exception;




import com.fs.common.core.domain.R;
import com.fs.common.exception.CustomException;
import com.fs.common.utils.ServletUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.security.access.AccessDeniedException;
import org.springframework.validation.BindException;
import org.springframework.validation.FieldError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.servlet.NoHandlerFoundException;

import javax.servlet.http.HttpServletRequest;
import java.io.BufferedReader;
import java.io.IOException;
import java.util.stream.Collectors;


/**
 * 异常处理器
 */
@RestControllerAdvice
public class FSExceptionHandler {
	private Logger logger = LoggerFactory.getLogger(getClass());

	/**
	 * 处理自定义异常
	 */
	@ExceptionHandler(FSException.class)
	public R handleRRException(FSException e){
		R r = new R();
		r.put("code", e.getCode());
		r.put("msg", e.getMessage());

		return r;
	}

	@ExceptionHandler(NoHandlerFoundException.class)
	public R handlerNoFoundException(Exception e) {
		logger.error(e.getMessage(), e);
		logger.error("handlerNoFoundException");
		return R.error(404, "路径不存在，请检查路径是否正确");
	}

	@ExceptionHandler(DuplicateKeyException.class)
	public R handleDuplicateKeyException(DuplicateKeyException e){
		logger.error(e.getMessage(), e);
		logger.error("handleDuplicateKeyException");
		return R.error("数据库中已存在该记录");
	}

	private String getRequestData(HttpServletRequest request) throws IOException {
		try (BufferedReader reader = request.getReader()) {
			return reader.lines().collect(Collectors.joining(System.lineSeparator()));
		}
	}
	@ExceptionHandler(IOException.class)
	public R handleIOException(Exception e, HttpServletRequest webRequest){
		logger.error("handleIOException");
		logger.error("请求数据: " + webRequest);
		logger.error("链接中断路径: " + webRequest.getRequestURI()+"请求数据: ");
		HttpServletRequest request = ServletUtils.getRequest();
		String requestData = "";
		try {
			// 尝试获取请求数据
			requestData = getRequestData(request);
		} catch (IOException ex) {
			// 若获取请求数据时再次出错，记录日志
			logger.error("获取请求数据时发生错误: " + ex.getMessage());

		}
		// 记录原始异常信息\
		logger.error("发生 IOException: " + e.getMessage());

		// 打印请求数据
		logger.error("请求数据: " + requestData);
		logger.error("请求数据2: " + webRequest);

		try{
			String requestPath = request.getRequestURI();
			// 打印或记录请求路径

			logger.error("链接中断路径: " + requestPath+"请求数据: " + requestData);
			logger.error("链接中断路径2: " + webRequest.getRequestURI()+"请求数据: " + webRequest);
			//todo  判断如果是进线，则重发一下欢迎语
		}
		catch (Exception e1){
			logger.error("获取url错误: ");
			HttpServletRequest request2 = ServletUtils.getRequest();
			logger.error("获取url错误路径: " + request2.getRequestURI());
		}
		return R.error();
	}
	@ExceptionHandler(Exception.class)
	public R handleException(Exception e){
		logger.error("handleException");
		logger.error(e.getMessage(), e);
		return R.error();
	}
	@ExceptionHandler(AccessDeniedException.class)
	public R handleAccessDeniedException(AccessDeniedException e){
		logger.error("handleAccessDeniedException");
		logger.error(e.getMessage(), e);
		return R.error("没有权限");
	}

	@ExceptionHandler(BindException.class)
	public R bindExceptionHandler(BindException e) {
		logger.error("bindExceptionHandler");
		FieldError error = e.getFieldError();
		String message = String.format("%s",  error.getDefaultMessage());
		return R.error(message);
	}

	@ExceptionHandler(MethodArgumentNotValidException.class)
	public R exceptionHandler(MethodArgumentNotValidException e) {
		FieldError error = e.getBindingResult().getFieldError();
		String message = String.format("%s",  error.getDefaultMessage());
		return R.error(message);
	}
	@ExceptionHandler(CustomException.class)
	public R handleException(CustomException e){
		logger.error("handleException");
		return R.error(e.getMessage());
	}
}
