package com.fs.chat.service;

import java.util.List;
import java.util.Map;

import com.fs.chat.domain.ChatMsg;
import com.fs.chat.param.ChatMsgListAParam;
import com.fs.chat.param.ChatMsgListCParam;
import com.fs.chat.vo.ChatMsgListAVO;
import com.fs.chat.vo.ChatMsgListCVO;
import com.fs.chat.vo.ChatMsgVO;

/**
 * 聊天消息记录Service接口
 *
 * @author fs
 * @date 2024-04-19
 */
public interface IChatMsgService
{
    /**
     * 查询聊天消息记录
     *
     * @param msgId 聊天消息记录主键
     * @return 聊天消息记录
     */
    public ChatMsg selectChatMsgByMsgId(Long msgId);

    /**
     * 查询聊天消息记录列表
     *
     * @param chatMsg 聊天消息记录
     * @return 聊天消息记录集合
     */
    public List<ChatMsg> selectChatMsgList(ChatMsg chatMsg);

    /**
     * 新增聊天消息记录
     *
     * @param chatMsg 聊天消息记录
     * @return 结果
     */
    public int insertChatMsg(ChatMsg chatMsg);

    /**
     * 修改聊天消息记录
     *
     * @param chatMsg 聊天消息记录
     * @return 结果
     */
    public int updateChatMsg(ChatMsg chatMsg);

    /**
     * 批量删除聊天消息记录
     *
     * @param msgIds 需要删除的聊天消息记录主键集合
     * @return 结果
     */
    public int deleteChatMsgByMsgIds(Long[] msgIds);

    /**
     * 删除聊天消息记录信息
     *
     * @param msgId 聊天消息记录主键
     * @return 结果
     */
    public int deleteChatMsgByMsgId(Long msgId);

    List<ChatMsgListCVO> selectChatMsgListCVO(ChatMsgListCParam param);

    int checkMsg(String extId);

    Map<String,Object> selectAllChatMsgByMsgId(Long msgId);

    String selectUserContent(Long msgId,String userId,Long roleId);

    List<ChatMsgVO> selectChatMsgBySessionId(Long sessionId);

    ChatMsgVO selectChatMsgVOByMsgId(Long msgId);

    List<ChatMsgListAVO> selectChatMsgListAVO(ChatMsgListAParam param);
}
