package com.fs.chat.service;

import java.util.List;
import com.fs.chat.domain.ChatSession;
import com.fs.chat.param.ChatSessionListCParam;
import com.fs.chat.vo.ChatSessionCVO;
import com.fs.chat.vo.ChatSessionListCVO;

/**
 * 会话Service接口
 *
 * @author fs
 * @date 2024-05-11
 */
public interface IChatSessionService
{
    /**
     * 查询会话
     *
     * @param sessionId 会话主键
     * @return 会话
     */
    public ChatSession selectChatSessionBySessionId(Long sessionId);

    /**
     * 查询会话列表
     *
     * @param chatSession 会话
     * @return 会话集合
     */
    public List<ChatSession> selectChatSessionList(ChatSession chatSession);

    /**
     * 新增会话
     *
     * @param chatSession 会话
     * @return 结果
     */
    public int insertChatSession(ChatSession chatSession);

    /**
     * 修改会话
     *
     * @param chatSession 会话
     * @return 结果
     */
    public int updateChatSession(ChatSession chatSession);

    /**
     * 批量删除会话
     *
     * @param sessionIds 需要删除的会话主键集合
     * @return 结果
     */
    public int deleteChatSessionBySessionIds(Long[] sessionIds);

    /**
     * 删除会话信息
     *
     * @param sessionId 会话主键
     * @return 结果
     */
    public int deleteChatSessionBySessionId(Long sessionId);

    List<ChatSessionListCVO> selectChatSessionListCVO(ChatSessionListCParam chatSession);

    ChatSessionCVO selectChatSessionCVOBySessionId(Long sessionId);

    ChatSession selectChatSessionByIds(String userId, String kfId);
}
