package com.fs.company.mapper;

import com.fs.company.domain.CompanyRole;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 角色信息Mapper接口
 *
 * @author fs
 * @date 2021-05-25
 */
public interface CompanyRoleMapper
{
    /**
     * 查询角色信息
     *
     * @param roleId 角色信息ID
     * @return 角色信息
     */
    public CompanyRole selectCompanyRoleById(Long roleId);

    /**
     * 查询角色信息列表
     *
     * @param companyRole 角色信息
     * @return 角色信息集合
     */
    public List<CompanyRole> selectCompanyRoleList(CompanyRole companyRole);

    /**
     * 新增角色信息
     *
     * @param companyRole 角色信息
     * @return 结果
     */
    public int insertCompanyRole(CompanyRole companyRole);

    /**
     * 修改角色信息
     *
     * @param companyRole 角色信息
     * @return 结果
     */
    public int updateCompanyRole(CompanyRole companyRole);

    /**
     * 删除角色信息
     *
     * @param roleId 角色信息ID
     * @return 结果
     */
    public int deleteCompanyRoleById(Long roleId);

    /**
     * 批量删除角色信息
     *
     * @param roleIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteCompanyRoleByIds(Long[] roleIds);

    List<CompanyRole> selectRolePermissionByUserId(Long userId);

    List<CompanyRole> selectRolesByUserName(String username);

    CompanyRole checkRoleNameUnique(@Param("roleName") String roleName, @Param("companyId") Long companyId);

    CompanyRole checkRoleKeyUnique(@Param("roleKey") String roleKey,@Param("companyId") Long companyId);

    List<Integer> selectRoleListByUserId(Long userId);

    /**
     * 根据ID集合查询角色列表
     * @param roleIds  ID集合
     * @return  list
     */
    List<CompanyRole> selectRoleListByIds(@Param("roleIds") List<Long> roleIds);
}
