package com.fs.company.mapper;

import com.fs.company.domain.CompanyTag;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * companyMapper接口
 *
 * @author fs
 * @date 2025-04-02
 */
public interface CompanyTagMapper
{
    /**
     * 查询company
     *
     * @param tagId companyID
     * @return company
     */
    public CompanyTag selectCompanyTagById(Long tagId);

    /**
     * 查询company列表
     *
     * @param companyTag company
     * @return company集合
     */
    public List<CompanyTag> selectCompanyTagList(CompanyTag companyTag);

    /**
     * 新增company
     *
     * @param companyTag company
     * @return 结果
     */
    public int insertCompanyTag(CompanyTag companyTag);

    /**
     * 修改company
     *
     * @param companyTag company
     * @return 结果
     */
    public int updateCompanyTag(CompanyTag companyTag);

    /**
     * 删除company
     *
     * @param tagId companyID
     * @return 结果
     */
    public int deleteCompanyTagById(Long tagId);

    /**
     * 批量删除company
     *
     * @param tagIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteCompanyTagByIds(Long[] tagIds);

    /**
     * 查询标签列表
     * @param params 条件
     * @return list
     */
    List<CompanyTag> selectCompanyTagListByMap(@Param("params") Map<String, Object> params);

    /**
     * 查询用户标签列表
     * @param userId    用户ID
     * @return  list
     */
    List<CompanyTag> selectCompanyTagListByUserId(@Param("userId") Long userId);

    String findUserTagByUserId(@Param("userId") Long userId,@Param("companyUserId") Long companyUserId);
    @MapKey("tagId")
    Map<Long,CompanyTag> queryAllTagMap();
}
