package com.fs.company.service;

import java.util.List;
import com.fs.company.domain.CompanySmsOrder;
import com.fs.company.param.CompanySmsOrderListParam;
import com.fs.company.vo.CompanySmsOrderListVO;

/**
 * 短信购买订单Service接口
 * 
 * @author fs
 * @date 2023-01-09
 */
public interface ICompanySmsOrderService 
{
    /**
     * 查询短信购买订单
     * 
     * @param orderId 短信购买订单ID
     * @return 短信购买订单
     */
    public CompanySmsOrder selectCompanySmsOrderById(Long orderId);

    /**
     * 查询短信购买订单列表
     * 
     * @param companySmsOrder 短信购买订单
     * @return 短信购买订单集合
     */
    public List<CompanySmsOrderListVO> selectCompanySmsOrderList(CompanySmsOrderListParam companySmsOrder);

    /**
     * 新增短信购买订单
     * 
     * @param companySmsOrder 短信购买订单
     * @return 结果
     */
    public int insertCompanySmsOrder(CompanySmsOrder companySmsOrder);

    /**
     * 修改短信购买订单
     * 
     * @param companySmsOrder 短信购买订单
     * @return 结果
     */
    public int updateCompanySmsOrder(CompanySmsOrder companySmsOrder);

    /**
     * 批量删除短信购买订单
     * 
     * @param orderIds 需要删除的短信购买订单ID
     * @return 结果
     */
    public int deleteCompanySmsOrderByIds(Long[] orderIds);

    /**
     * 删除短信购买订单信息
     * 
     * @param orderId 短信购买订单ID
     * @return 结果
     */
    public int deleteCompanySmsOrderById(Long orderId);
}
