package com.fs.company.service;

import com.fs.company.domain.CompanyTcmReport;
import com.fs.company.param.CompanyTcmReportListQueryParam;
import com.fs.company.vo.CompanyReportExportVO;
import com.fs.company.vo.CompanyTcmReportExportVO;
import com.fs.company.vo.CompanyTcmReportListVO;
import com.fs.company.vo.CompanyTcmStatisticsExportVO;

import java.util.List;

/**
 * 中医档期业绩报表Service接口
 *
 * @author fs
 * @date 2023-09-05
 */
public interface ICompanyTcmReportService
{
    /**
     * 查询中医档期业绩报表
     *
     * @param id 中医档期业绩报表ID
     * @return 中医档期业绩报表
     */
    public CompanyTcmReport selectCompanyTcmReportById(Long id);

    /**
     * 查询中医档期业绩报表列表
     *
     * @param companyTcmReport 中医档期业绩报表
     * @return 中医档期业绩报表集合
     */
    public List<CompanyTcmReport> selectCompanyTcmReportList(CompanyTcmReport companyTcmReport);

    public List<CompanyTcmReportListVO> selectCompanyTcmReportListVOList(CompanyTcmReportListQueryParam companyTcmReport);

    public List<CompanyTcmReportExportVO> selectCompanyTcmReportExportVOList(CompanyTcmReportListQueryParam companyTcmReport);

    public List<CompanyTcmReportListVO> selectCompanyTcmReportStatisticsVOList(CompanyTcmReportListQueryParam param);

    public List<CompanyTcmStatisticsExportVO> selectCompanyTcmStatisticsExportVOList(CompanyTcmReportListQueryParam param);

    public List<CompanyReportExportVO> selectCompanyReportExportVOList(CompanyTcmReportListQueryParam param);

    public List<CompanyTcmReportListVO> selectReportStatisticsByScheduleId(CompanyTcmReportListQueryParam param);


    /**
     * 新增中医档期业绩报表
     *
     * @param companyTcmReport 中医档期业绩报表
     * @return 结果
     */
    public int insertCompanyTcmReport(CompanyTcmReport companyTcmReport);

    /**
     * 修改中医档期业绩报表
     *
     * @param companyTcmReport 中医档期业绩报表
     * @return 结果
     */
    public int updateCompanyTcmReport(CompanyTcmReport companyTcmReport);

    /**
     * 批量删除中医档期业绩报表
     *
     * @param ids 需要删除的中医档期业绩报表ID
     * @return 结果
     */
    public int deleteCompanyTcmReportByIds(Long[] ids);

    /**
     * 删除中医档期业绩报表信息
     *
     * @param id 中医档期业绩报表ID
     * @return 结果
     */
    public int deleteCompanyTcmReportById(Long id);
}
