package com.fs.company.service;

import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSONObject;
import com.fs.company.domain.CompanyVoiceLogs;
import com.fs.company.param.CompanyStatisticsParam;
import com.fs.company.param.CompanyVoiceLogsListQueryParam;
import com.fs.company.param.CompanyVoiceLogsParam;
import com.fs.company.vo.CompanyVoiceLogsExportVO;
import com.fs.company.vo.CompanyVoiceLogsListVO;
import com.fs.company.vo.CompanyVoiceLogsStatisticsVO;
import com.fs.company.vo.CompanyVoiceLogsVO;

/**
 * 通话记录Service接口
 *
 * @author fs
 * @date 2021-10-04
 */
public interface ICompanyVoiceLogsService
{
    /**
     * 查询通话记录
     *
     * @param voiceId 通话记录ID
     * @return 通话记录
     */
    public CompanyVoiceLogs selectCompanyVoiceLogsById(Long voiceId);

    /**
     * 查询通话记录列表
     *
     * @param companyVoiceLogs 通话记录
     * @return 通话记录集合
     */
    public List<CompanyVoiceLogs> selectCompanyVoiceLogsList(CompanyVoiceLogs companyVoiceLogs);

    /**
     * 新增通话记录
     *
     * @param companyVoiceLogs 通话记录
     * @return 结果
     */
    public int insertCompanyVoiceLogs(CompanyVoiceLogs companyVoiceLogs);

    /**
     * 修改通话记录
     *
     * @param companyVoiceLogs 通话记录
     * @return 结果
     */
    public int updateCompanyVoiceLogs(CompanyVoiceLogs companyVoiceLogs);

    /**
     * 批量删除通话记录
     *
     * @param voiceIds 需要删除的通话记录ID
     * @return 结果
     */
    public int deleteCompanyVoiceLogsByIds(Long[] voiceIds);

    /**
     * 删除通话记录信息
     *
     * @param voiceId 通话记录ID
     * @return 结果
     */
    public int deleteCompanyVoiceLogsById(Long voiceId);

    List<CompanyVoiceLogsVO> selectCompanyVoiceLogsVOList(CompanyVoiceLogsParam param);

    List<CompanyVoiceLogsExportVO> selectCompanyVoiceLogsExportVOList(CompanyVoiceLogsParam param);

    CompanyVoiceLogs selectCompanyVoiceLogsBySessionId(String sessionId);

    Integer selectCompanyVoiceLogsCount();

    Integer selectCompanyVoiceLogsCountByCallerMobile(String callerMobile,Integer type);

    Integer selectCompanyVoiceLogsCountByCalleeMobile(String calleeNbr,Integer type);

    List<CompanyVoiceLogsStatisticsVO> selectVoiceLogsStatisticsList(CompanyStatisticsParam param);

    List<JSONObject> selectVoiceLogsTotalCount(Map<String, Object> toMap);

    List<CompanyVoiceLogsListVO> selectCompanyVoiceLogsListQuery(CompanyVoiceLogsListQueryParam param);
}
