package com.fs.company.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.company.domain.CompanyPost;
import com.fs.company.mapper.CompanyPostMapper;
import com.fs.company.service.ICompanyPostService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;

/**
 * 岗位信息Service业务层处理
 *
 * @author fs
 * @date 2021-05-25
 */
@Service
public class CompanyPostServiceImpl implements ICompanyPostService
{
    @Autowired
    private CompanyPostMapper companyPostMapper;

    /**
     * 查询岗位信息
     *
     * @param postId 岗位信息ID
     * @return 岗位信息
     */
    @Override
    public CompanyPost selectCompanyPostById(Long postId)
    {
        return companyPostMapper.selectCompanyPostById(postId);
    }

    /**
     * 查询岗位信息列表
     *
     * @param companyPost 岗位信息
     * @return 岗位信息
     */
    @Override
    public List<CompanyPost> selectCompanyPostList(CompanyPost companyPost)
    {
        return companyPostMapper.selectCompanyPostList(companyPost);
    }

    /**
     * 新增岗位信息
     *
     * @param companyPost 岗位信息
     * @return 结果
     */
    @Override
    public int insertCompanyPost(CompanyPost companyPost)
    {
        companyPost.setCreateTime(DateUtils.getNowDate());
        return companyPostMapper.insertCompanyPost(companyPost);
    }

    /**
     * 修改岗位信息
     *
     * @param companyPost 岗位信息
     * @return 结果
     */
    @Override
    public int updateCompanyPost(CompanyPost companyPost)
    {
        companyPost.setUpdateTime(DateUtils.getNowDate());
        return companyPostMapper.updateCompanyPost(companyPost);
    }

    /**
     * 批量删除岗位信息
     *
     * @param postIds 需要删除的岗位信息ID
     * @return 结果
     */
    @Override
    public int deleteCompanyPostByIds(Long[] postIds)
    {
        return companyPostMapper.deleteCompanyPostByIds(postIds);
    }

    /**
     * 删除岗位信息信息
     *
     * @param postId 岗位信息ID
     * @return 结果
     */
    @Override
    public int deleteCompanyPostById(Long postId)
    {
        return companyPostMapper.deleteCompanyPostById(postId);
    }

    @Override
    public int checkPostCodeUnique(CompanyPost post) {
        return companyPostMapper.checkPostCodeUnique(post.getCompanyId(),post.getPostCode());
    }

    @Override
    public List<Integer> selectPostListByUserId(Long userId) {
        return companyPostMapper.selectPostListByUserId(userId);
    }

    @Override
    public List<String> selectPostNameListByUserId(Long userId) {
        return companyPostMapper.selectPostNameListByUserId(userId);
    }

    @Override
    public List<CompanyPost> selectCompanyPostListByUserId(Long userId) {
        return companyPostMapper.selectCompanyPostByUserId(userId);
    }

    @Override
    public List<CompanyPost> selectCompanyPostByIds(List<Long> postIds) {
        return companyPostMapper.selectCompanyPostByIds(postIds);
    }
}
