package com.fs.company.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.company.mapper.CompanyProfitLogsMapper;
import com.fs.company.domain.CompanyProfitLogs;
import com.fs.company.service.ICompanyProfitLogsService;

/**
 * 提现审核记录Service业务层处理
 * 
 * @author fs
 * @date 2022-10-28
 */
@Service
public class CompanyProfitLogsServiceImpl implements ICompanyProfitLogsService 
{
    @Autowired
    private CompanyProfitLogsMapper companyProfitLogsMapper;

    /**
     * 查询提现审核记录
     * 
     * @param logsId 提现审核记录ID
     * @return 提现审核记录
     */
    @Override
    public CompanyProfitLogs selectCompanyProfitLogsById(Long logsId)
    {
        return companyProfitLogsMapper.selectCompanyProfitLogsById(logsId);
    }

    /**
     * 查询提现审核记录列表
     * 
     * @param companyProfitLogs 提现审核记录
     * @return 提现审核记录
     */
    @Override
    public List<CompanyProfitLogs> selectCompanyProfitLogsList(CompanyProfitLogs companyProfitLogs)
    {
        return companyProfitLogsMapper.selectCompanyProfitLogsList(companyProfitLogs);
    }

    /**
     * 新增提现审核记录
     * 
     * @param companyProfitLogs 提现审核记录
     * @return 结果
     */
    @Override
    public int insertCompanyProfitLogs(CompanyProfitLogs companyProfitLogs)
    {
        companyProfitLogs.setCreateTime(DateUtils.getNowDate());
        return companyProfitLogsMapper.insertCompanyProfitLogs(companyProfitLogs);
    }

    /**
     * 修改提现审核记录
     * 
     * @param companyProfitLogs 提现审核记录
     * @return 结果
     */
    @Override
    public int updateCompanyProfitLogs(CompanyProfitLogs companyProfitLogs)
    {
        return companyProfitLogsMapper.updateCompanyProfitLogs(companyProfitLogs);
    }

    /**
     * 批量删除提现审核记录
     * 
     * @param logsIds 需要删除的提现审核记录ID
     * @return 结果
     */
    @Override
    public int deleteCompanyProfitLogsByIds(Long[] logsIds)
    {
        return companyProfitLogsMapper.deleteCompanyProfitLogsByIds(logsIds);
    }

    /**
     * 删除提现审核记录信息
     * 
     * @param logsId 提现审核记录ID
     * @return 结果
     */
    @Override
    public int deleteCompanyProfitLogsById(Long logsId)
    {
        return companyProfitLogsMapper.deleteCompanyProfitLogsById(logsId);
    }
}
