package com.fs.company.service.impl;

import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSONObject;
import com.fs.common.annotation.DataScope;
import com.fs.common.utils.DateUtils;
import com.fs.company.param.CompanySmsLogsListParam;
import com.fs.company.param.CompanySmsLogsListQueryParam;
import com.fs.company.param.CompanyStatisticsParam;
import com.fs.company.vo.CompanySmsLogsListQueryVO;
import com.fs.company.vo.CompanySmsLogsListVO;
import com.fs.company.vo.CompanySmsLogsStatisticsVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.company.mapper.CompanySmsLogsMapper;
import com.fs.company.domain.CompanySmsLogs;
import com.fs.company.service.ICompanySmsLogsService;

/**
 * 短信发送记录Service业务层处理
 *
 * @author fs
 * @date 2023-01-09
 */
@Service
public class CompanySmsLogsServiceImpl implements ICompanySmsLogsService
{
    @Autowired
    private CompanySmsLogsMapper companySmsLogsMapper;

    /**
     * 查询短信发送记录
     *
     * @param logsId 短信发送记录ID
     * @return 短信发送记录
     */
    @Override
    public CompanySmsLogs selectCompanySmsLogsById(Long logsId)
    {
        return companySmsLogsMapper.selectCompanySmsLogsById(logsId);
    }

    /**
     * 查询短信发送记录列表
     *
     * @return 短信发送记录
     */
    @Override
    public List<CompanySmsLogsListVO> selectCompanySmsLogsList(CompanySmsLogsListParam param)
    {
        return companySmsLogsMapper.selectCompanySmsLogsList(param);
    }

    /**
     * 新增短信发送记录
     *
     * @param companySmsLogs 短信发送记录
     * @return 结果
     */
    @Override
    public int insertCompanySmsLogs(CompanySmsLogs companySmsLogs)
    {
        if(companySmsLogs.getCreateTime()==null){
            companySmsLogs.setCreateTime(DateUtils.getNowDate());
        }
        return companySmsLogsMapper.insertCompanySmsLogs(companySmsLogs);
    }

    /**
     * 修改短信发送记录
     *
     * @param companySmsLogs 短信发送记录
     * @return 结果
     */
    @Override
    public int updateCompanySmsLogs(CompanySmsLogs companySmsLogs)
    {
        return companySmsLogsMapper.updateCompanySmsLogs(companySmsLogs);
    }

    /**
     * 批量删除短信发送记录
     *
     * @param logsIds 需要删除的短信发送记录ID
     * @return 结果
     */
    @Override
    public int deleteCompanySmsLogsByIds(Long[] logsIds)
    {
        return companySmsLogsMapper.deleteCompanySmsLogsByIds(logsIds);
    }

    /**
     * 删除短信发送记录信息
     *
     * @param logsId 短信发送记录ID
     * @return 结果
     */
    @Override
    public int deleteCompanySmsLogsById(Long logsId)
    {
        return companySmsLogsMapper.deleteCompanySmsLogsById(logsId);
    }

    @Override
    @DataScope(deptAlias = "u",userAlias = "u")
    public List<CompanySmsLogsListQueryVO> selectCompanySmsLogsListQuery(CompanySmsLogsListQueryParam param) {
        return companySmsLogsMapper.selectCompanySmsLogsListQuery(param);
    }

    @Override
    public CompanySmsLogs selectCompanySmsLogsByMid(String mid) {
        return companySmsLogsMapper.selectCompanySmsLogsByMid(mid);
    }

    @Override
    public List<JSONObject> selectSmsLogsCounts(Map<String, Object> toMap) {
        return companySmsLogsMapper.selectSmsLogsCounts(toMap);
    }

    @Override
    public List<CompanySmsLogsStatisticsVO> selectSmsLogsStatisticsList(CompanyStatisticsParam param) {
        return companySmsLogsMapper.selectSmsLogsStatisticsList(param);
    }

    @Override
    public CompanySmsLogs selectCompanySmsLogsByMobile(String mobile) {
        return companySmsLogsMapper.selectCompanySmsLogsByMobile(mobile);
    }


}
