package com.fs.company.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.fs.company.param.CompanySmsOrderListParam;
import com.fs.company.vo.CompanySmsOrderListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.company.mapper.CompanySmsOrderMapper;
import com.fs.company.domain.CompanySmsOrder;
import com.fs.company.service.ICompanySmsOrderService;

/**
 * 短信购买订单Service业务层处理
 * 
 * @author fs
 * @date 2023-01-09
 */
@Service
public class CompanySmsOrderServiceImpl implements ICompanySmsOrderService 
{
    @Autowired
    private CompanySmsOrderMapper companySmsOrderMapper;

    /**
     * 查询短信购买订单
     * 
     * @param orderId 短信购买订单ID
     * @return 短信购买订单
     */
    @Override
    public CompanySmsOrder selectCompanySmsOrderById(Long orderId)
    {
        return companySmsOrderMapper.selectCompanySmsOrderById(orderId);
    }

    /**
     * 查询短信购买订单列表
     * 
     * @param companySmsOrder 短信购买订单
     * @return 短信购买订单
     */
    @Override
    public List<CompanySmsOrderListVO> selectCompanySmsOrderList(CompanySmsOrderListParam companySmsOrder)
    {
        return companySmsOrderMapper.selectCompanySmsOrderList(companySmsOrder);
    }

    /**
     * 新增短信购买订单
     * 
     * @param companySmsOrder 短信购买订单
     * @return 结果
     */
    @Override
    public int insertCompanySmsOrder(CompanySmsOrder companySmsOrder)
    {
        companySmsOrder.setCreateTime(DateUtils.getNowDate());
        return companySmsOrderMapper.insertCompanySmsOrder(companySmsOrder);
    }

    /**
     * 修改短信购买订单
     * 
     * @param companySmsOrder 短信购买订单
     * @return 结果
     */
    @Override
    public int updateCompanySmsOrder(CompanySmsOrder companySmsOrder)
    {
        return companySmsOrderMapper.updateCompanySmsOrder(companySmsOrder);
    }

    /**
     * 批量删除短信购买订单
     * 
     * @param orderIds 需要删除的短信购买订单ID
     * @return 结果
     */
    @Override
    public int deleteCompanySmsOrderByIds(Long[] orderIds)
    {
        return companySmsOrderMapper.deleteCompanySmsOrderByIds(orderIds);
    }

    /**
     * 删除短信购买订单信息
     * 
     * @param orderId 短信购买订单ID
     * @return 结果
     */
    @Override
    public int deleteCompanySmsOrderById(Long orderId)
    {
        return companySmsOrderMapper.deleteCompanySmsOrderById(orderId);
    }
}
