package com.fs.company.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.fs.company.param.CompanySmsTempListQueryParam;
import com.fs.company.vo.CompanySmsTempListQueryVO;
import com.fs.company.vo.CompanySmsTempListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.company.mapper.CompanySmsTempMapper;
import com.fs.company.domain.CompanySmsTemp;
import com.fs.company.service.ICompanySmsTempService;

/**
 * 短信模板Service业务层处理
 * 
 * @author fs
 * @date 2023-01-09
 */
@Service
public class CompanySmsTempServiceImpl implements ICompanySmsTempService 
{
    @Autowired
    private CompanySmsTempMapper companySmsTempMapper;

    /**
     * 查询短信模板
     * 
     * @param tempId 短信模板ID
     * @return 短信模板
     */
    @Override
    public CompanySmsTemp selectCompanySmsTempById(Long tempId)
    {
        return companySmsTempMapper.selectCompanySmsTempById(tempId);
    }

    /**
     * 查询短信模板列表
     * 
     * @param companySmsTemp 短信模板
     * @return 短信模板
     */
    @Override
    public List<CompanySmsTemp> selectCompanySmsTempList(CompanySmsTemp companySmsTemp)
    {
        return companySmsTempMapper.selectCompanySmsTempList(companySmsTemp);
    }

    /**
     * 新增短信模板
     * 
     * @param companySmsTemp 短信模板
     * @return 结果
     */
    @Override
    public int insertCompanySmsTemp(CompanySmsTemp companySmsTemp)
    {
        companySmsTemp.setCreateTime(DateUtils.getNowDate());
        return companySmsTempMapper.insertCompanySmsTemp(companySmsTemp);
    }

    /**
     * 修改短信模板
     * 
     * @param companySmsTemp 短信模板
     * @return 结果
     */
    @Override
    public int updateCompanySmsTemp(CompanySmsTemp companySmsTemp)
    {
        companySmsTemp.setUpdateTime(DateUtils.getNowDate());
        return companySmsTempMapper.updateCompanySmsTemp(companySmsTemp);
    }

    /**
     * 批量删除短信模板
     * 
     * @param tempIds 需要删除的短信模板ID
     * @return 结果
     */
    @Override
    public int deleteCompanySmsTempByIds(Long[] tempIds)
    {
        return companySmsTempMapper.deleteCompanySmsTempByIds(tempIds);
    }

    /**
     * 删除短信模板信息
     * 
     * @param tempId 短信模板ID
     * @return 结果
     */
    @Override
    public int deleteCompanySmsTempById(Long tempId)
    {
        return companySmsTempMapper.deleteCompanySmsTempById(tempId);
    }

    @Override
    public CompanySmsTemp selectCompanySmsTempByCode(String tempCode) {
        return companySmsTempMapper.selectCompanySmsTempByCode(tempCode);
    }

    @Override
    public List<CompanySmsTempListVO> selectCompanySmsTempListVO(CompanySmsTemp companySmsTemp) {
        return companySmsTempMapper.selectCompanySmsTempListVO(companySmsTemp);
    }

    @Override
    public List<CompanySmsTempListQueryVO> selectCompanySmsTempListQuery(CompanySmsTempListQueryParam companySmsTemp) {
        return companySmsTempMapper.selectCompanySmsTempListQuery(companySmsTemp);
    }
}
