package com.fs.company.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.company.mapper.CompanyUserDelayTimeMapper;
import com.fs.company.domain.CompanyUserDelayTime;
import com.fs.company.service.ICompanyUserDelayTimeService;

/**
 * 员工发送延时时间关联Service业务层处理
 *
 * @author fs
 * @date 2025-06-18
 */
@Service
public class CompanyUserDelayTimeServiceImpl extends ServiceImpl<CompanyUserDelayTimeMapper, CompanyUserDelayTime> implements ICompanyUserDelayTimeService {

    /**
     * 查询员工发送延时时间关联
     *
     * @param id 员工发送延时时间关联主键
     * @return 员工发送延时时间关联
     */
    @Override
    public CompanyUserDelayTime selectCompanyUserDelayTimeById(Long id)
    {
        return baseMapper.selectCompanyUserDelayTimeById(id);
    }

    /**
     * 查询员工发送延时时间关联列表
     *
     * @param companyUserDelayTime 员工发送延时时间关联
     * @return 员工发送延时时间关联
     */
    @Override
    public List<CompanyUserDelayTime> selectCompanyUserDelayTimeList(CompanyUserDelayTime companyUserDelayTime)
    {
        return baseMapper.selectCompanyUserDelayTimeList(companyUserDelayTime);
    }

    /**
     * 新增员工发送延时时间关联
     *
     * @param companyUserDelayTime 员工发送延时时间关联
     * @return 结果
     */
    @Override
    public int insertCompanyUserDelayTime(CompanyUserDelayTime companyUserDelayTime)
    {
        companyUserDelayTime.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertCompanyUserDelayTime(companyUserDelayTime);
    }

    /**
     * 修改员工发送延时时间关联
     *
     * @param companyUserDelayTime 员工发送延时时间关联
     * @return 结果
     */
    @Override
    public int updateCompanyUserDelayTime(CompanyUserDelayTime companyUserDelayTime)
    {
        companyUserDelayTime.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateCompanyUserDelayTime(companyUserDelayTime);
    }

    /**
     * 批量删除员工发送延时时间关联
     *
     * @param ids 需要删除的员工发送延时时间关联主键
     * @return 结果
     */
    @Override
    public int deleteCompanyUserDelayTimeByIds(Long[] ids)
    {
        return baseMapper.deleteCompanyUserDelayTimeByIds(ids);
    }

    /**
     * 删除员工发送延时时间关联信息
     *
     * @param id 员工发送延时时间关联主键
     * @return 结果
     */
    @Override
    public int deleteCompanyUserDelayTimeById(Long id)
    {
        return baseMapper.deleteCompanyUserDelayTimeById(id);
    }

    /**
     * 通过员工id和企业id查询数据信息
     *
     * @param companyId
     * @param userId
     * @return
     */
    @Override
    public CompanyUserDelayTime selectCompanyUserDelayTimeByCompanyUser(Long companyId, Long userId) {
        return baseMapper.selectUserDelayTimeByCompanyUserId(userId,companyId);
    }
}
