package com.fs.company.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.company.mapper.CompanyVoicePackageMapper;
import com.fs.company.domain.CompanyVoicePackage;
import com.fs.company.service.ICompanyVoicePackageService;

/**
 * 套餐Service业务层处理
 * 
 * @author fs
 * @date 2023-02-23
 */
@Service
public class CompanyVoicePackageServiceImpl implements ICompanyVoicePackageService 
{
    @Autowired
    private CompanyVoicePackageMapper companyVoicePackageMapper;

    /**
     * 查询套餐
     * 
     * @param packageId 套餐ID
     * @return 套餐
     */
    @Override
    public CompanyVoicePackage selectCompanyVoicePackageById(Long packageId)
    {
        return companyVoicePackageMapper.selectCompanyVoicePackageById(packageId);
    }

    /**
     * 查询套餐列表
     * 
     * @param companyVoicePackage 套餐
     * @return 套餐
     */
    @Override
    public List<CompanyVoicePackage> selectCompanyVoicePackageList(CompanyVoicePackage companyVoicePackage)
    {
        return companyVoicePackageMapper.selectCompanyVoicePackageList(companyVoicePackage);
    }

    /**
     * 新增套餐
     * 
     * @param companyVoicePackage 套餐
     * @return 结果
     */
    @Override
    public int insertCompanyVoicePackage(CompanyVoicePackage companyVoicePackage)
    {
        return companyVoicePackageMapper.insertCompanyVoicePackage(companyVoicePackage);
    }

    /**
     * 修改套餐
     * 
     * @param companyVoicePackage 套餐
     * @return 结果
     */
    @Override
    public int updateCompanyVoicePackage(CompanyVoicePackage companyVoicePackage)
    {
        return companyVoicePackageMapper.updateCompanyVoicePackage(companyVoicePackage);
    }

    /**
     * 批量删除套餐
     * 
     * @param packageIds 需要删除的套餐ID
     * @return 结果
     */
    @Override
    public int deleteCompanyVoicePackageByIds(Long[] packageIds)
    {
        return companyVoicePackageMapper.deleteCompanyVoicePackageByIds(packageIds);
    }

    /**
     * 删除套餐信息
     * 
     * @param packageId 套餐ID
     * @return 结果
     */
    @Override
    public int deleteCompanyVoicePackageById(Long packageId)
    {
        return companyVoicePackageMapper.deleteCompanyVoicePackageById(packageId);
    }
}
