package com.fs.course.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.common.annotation.DataSource;
import com.fs.common.enums.DataSourceType;
import com.fs.course.domain.FsVideoBarrage;
import com.fs.course.param.FsVideoBarrageQueryParam;
import com.fs.course.vo.FsVideoBarrageVO;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.List;

/**
 * 视频弹幕Mapper接口
 *
 * @author fs
 * @date 2025-04-07
 */
@Repository
public interface FsVideoBarrageMapper extends BaseMapper<FsVideoBarrage>{
    /**
     * 查询视频弹幕
     *
     * @param id 视频弹幕主键
     * @return 视频弹幕
     */
    FsVideoBarrage selectFsVideoBarrageById(String id);

    /**
     * 查询视频弹幕列表
     *
     * @param fsVideoBarrage 视频弹幕
     * @return 视频弹幕集合
     */
    @DataSource(DataSourceType.SLAVE)
    List<FsVideoBarrageVO> selectFsVideoBarrageList(FsVideoBarrageQueryParam fsVideoBarrage);

    /**
     * 新增视频弹幕
     *
     * @param fsVideoBarrage 视频弹幕
     * @return 结果
     */
    int insertFsVideoBarrage(FsVideoBarrage fsVideoBarrage);

    /**
     * 修改视频弹幕
     *
     * @param fsVideoBarrage 视频弹幕
     * @return 结果
     */
    int updateFsVideoBarrage(FsVideoBarrage fsVideoBarrage);

    /**
     * 删除视频弹幕
     *
     * @param id 视频弹幕主键
     * @return 结果
     */
    int deleteFsVideoBarrageById(String id);

    /**
     * 批量删除视频弹幕
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsVideoBarrageByIds(String[] ids);


    int insertBarrage(FsVideoBarrage barrage);


    List<FsVideoBarrage> selectByVideoId(@Param("videoId") Long videoId);


    List<FsVideoBarrage> selectBySegment(@Param("videoId") Long videoId, @Param("start") int start, @Param("end") int end);

    int updateStatus(@Param("id") Long id, @Param("status") String status);

    int batchUpdateStatus(@Param("ids") ArrayList ids, @Param("status")String status);

}
