package com.fs.course.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.common.core.domain.R;
import com.fs.course.domain.FsUserCoursePeriodDays;
import com.fs.course.param.CompanyRedPacketParam;
import com.fs.course.param.PeriodCountParam;
import com.fs.course.vo.FsPeriodCountVO;
import com.fs.course.vo.PeriodRedPacketVO;
import com.fs.course.vo.UpdateCourseTimeVo;
import com.fs.his.vo.OptionsVO;

import java.util.List;
import java.util.Map;

/**
 * 营期课程Service接口
 *
 * @author fs
 * @date 2025-04-16
 */
public interface IFsUserCoursePeriodDaysService extends IService<FsUserCoursePeriodDays>{
    /**
     * 查询营期课程
     *
     * @param id 营期课程主键
     * @return 营期课程
     */
    FsUserCoursePeriodDays selectFsUserCoursePeriodDaysById(Long id);

    /**
     * 查询营期课程列表
     *
     * @param fsUserCoursePeriodDays 营期课程
     * @return 营期课程集合
     */
    List<FsUserCoursePeriodDays> selectFsUserCoursePeriodDaysList(FsUserCoursePeriodDays fsUserCoursePeriodDays);

    /**
     * 新增营期课程
     *
     * @param fsUserCoursePeriodDays 营期课程
     * @return 结果
     */
    int insertFsUserCoursePeriodDays(FsUserCoursePeriodDays fsUserCoursePeriodDays);

    /**
     * 修改营期课程
     *
     * @param fsUserCoursePeriodDays 营期课程
     * @return 结果
     */
    int updateFsUserCoursePeriodDays(FsUserCoursePeriodDays fsUserCoursePeriodDays);

    /**
     * 批量删除营期课程
     *
     * @param ids 需要删除的营期课程主键集合
     * @return 结果
     */
    int deleteFsUserCoursePeriodDaysByIds(Long[] ids);

    /**
     * 删除营期课程信息
     *
     * @param id 营期课程主键
     * @return 结果
     */
    int deleteFsUserCoursePeriodDaysById(Long id);

    R addCourse(FsUserCoursePeriodDays entity);

    R updateListCourseData(List<FsUserCoursePeriodDays> entity);

    /**
     * 根据营期id获取关联的公司
     * @param periodId 营期id
     * @param videoId 视频id
     * @return
     */
    List<CompanyRedPacketParam> getCompanyByPeriod(Long periodId, Long videoId);

    /**
     *
     * @param periodId 营期id
     * @param companyId 公司id
     * @return
     */
    List<PeriodRedPacketVO> getPeriodRedPacketList(Long periodId, Long companyId);

    /**
     * 根据营期按课程统计
     * @param param
     * @return
     */
    List<FsPeriodCountVO> periodCourseCount(PeriodCountParam param);

    /**
     * 查询营期选项列表
     * @param params    参数
     * @return  list
     */
    List<OptionsVO> selectPeriodListByMap(Map<String, Object> params);

    /**
     * 上移/下移（调整课程的营期时间）
     * @param id 当前数据
     * @param targetId 需要移动到的数据
     * @return
     */
    R periodCourseMove(Long id, Long targetId);

    R updateCourseTime(UpdateCourseTimeVo vo);

    R updateCourseDate(UpdateCourseTimeVo vo);
    /**
     * 更新营期课程状态
     */
    void changePeriodCourseStatus();
}
