package com.fs.course.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.course.mapper.FsCourseDomainNameMapper;
import com.fs.course.domain.FsCourseDomainName;
import com.fs.course.service.IFsCourseDomainNameService;

/**
 * 课程短链域名Service业务层处理
 * 
 * @author fs
 * @date 2024-10-09
 */
@Service
public class FsCourseDomainNameServiceImpl implements IFsCourseDomainNameService 
{
    @Autowired
    private FsCourseDomainNameMapper fsCourseDomainNameMapper;

    /**
     * 查询课程短链域名
     * 
     * @param id 课程短链域名主键
     * @return 课程短链域名
     */
    @Override
    public FsCourseDomainName selectFsCourseDomainNameById(Long id)
    {
        return fsCourseDomainNameMapper.selectFsCourseDomainNameById(id);
    }

    /**
     * 查询课程短链域名列表
     * 
     * @param fsCourseDomainName 课程短链域名
     * @return 课程短链域名
     */
    @Override
    public List<FsCourseDomainName> selectFsCourseDomainNameList(FsCourseDomainName fsCourseDomainName)
    {
        return fsCourseDomainNameMapper.selectFsCourseDomainNameList(fsCourseDomainName);
    }

    /**
     * 新增课程短链域名
     * 
     * @param fsCourseDomainName 课程短链域名
     * @return 结果
     */
    @Override
    public int insertFsCourseDomainName(FsCourseDomainName fsCourseDomainName)
    {
        fsCourseDomainName.setCreateTime(DateUtils.getNowDate());
        return fsCourseDomainNameMapper.insertFsCourseDomainName(fsCourseDomainName);
    }

    /**
     * 修改课程短链域名
     * 
     * @param fsCourseDomainName 课程短链域名
     * @return 结果
     */
    @Override
    public int updateFsCourseDomainName(FsCourseDomainName fsCourseDomainName)
    {
        fsCourseDomainName.setUpdateTime(DateUtils.getNowDate());
        return fsCourseDomainNameMapper.updateFsCourseDomainName(fsCourseDomainName);
    }

    /**
     * 批量删除课程短链域名
     * 
     * @param ids 需要删除的课程短链域名主键
     * @return 结果
     */
    @Override
    public int deleteFsCourseDomainNameByIds(Long[] ids)
    {
        return fsCourseDomainNameMapper.deleteFsCourseDomainNameByIds(ids);
    }

    /**
     * 删除课程短链域名信息
     * 
     * @param id 课程短链域名主键
     * @return 结果
     */
    @Override
    public int deleteFsCourseDomainNameById(Long id)
    {
        return fsCourseDomainNameMapper.deleteFsCourseDomainNameById(id);
    }
}
