package com.fs.erp.dto.sdk.HzOMS.api;

import cn.hutool.core.date.DateUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONObject;
import com.fs.common.core.redis.RedisCache;
import com.fs.common.utils.StringUtils;
import com.fs.his.config.FsSysConfig;
import com.fs.his.utils.ConfigUtil;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.Header;
import org.apache.http.HttpEntity;
import org.apache.http.entity.StringEntity;
import org.apache.http.client.methods.HttpPost;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.nio.charset.StandardCharsets;
import java.util.Calendar;
import java.util.HashMap;
import java.util.concurrent.TimeUnit;

import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;

@Component
@Slf4j
public class HzOMSClient {

    @Autowired
    private ConfigUtil configUtil;

    @Autowired
    private RedisCache redisCache;

    private final String TOKEN_URL = "0";

    private final String EXEC_RULE_URL = "1";

    private final String HZOMS_TOKEN_KEY = "erp::hzoms::token";

    /**
     * 根据规则名称发送请求
     *
     * @param ruleName
     * @return
     */
    public JSONObject send(String ruleName, JSONObject params) {
        CloseableHttpClient client = null;
        try {
            client = HttpClients.createDefault();
            HttpPost httpPost = new HttpPost(getRequestUrl(EXEC_RULE_URL));
            JSONObject bodyObj = new JSONObject();
            bodyObj.put("ruleName", ruleName);
            bodyObj.put("dataPackage", params);
            log.info("瀚智OMS请求参数打印：{}", bodyObj.toJSONString());
            StringEntity entity = new StringEntity(bodyObj.toJSONString(),"UTF-8");
            httpPost.setEntity(entity);
//            httpPost.setHeader("Accept", "application/json");
            httpPost.setHeader("Content-type", "application/json");
            httpPost.setHeader("token", getToken());
            httpPost.setHeader("itenantid", getItenantid());
            HttpEntity response = client.execute(httpPost).getEntity();
            String responseString = EntityUtils.toString(response);
            log.info(" 执行动作," + ruleName + "瀚智OMS接口响应数据:{}", responseString);
            JSONObject jsonObject = JSONObject.parseObject(responseString);
            if(null != jsonObject && !jsonObject.isEmpty() && jsonObject.containsKey("code") && !"200".equals(jsonObject.getString("code"))){
                log.info("瀚智OMS接口报错了，错误信息：{}", jsonObject.getString("message"));
            }
            return jsonObject;
        } catch (UnsupportedEncodingException e) {
            log.error("请求参数编码异常", e);
            throw new RuntimeException("请求参数编码异常", e);
        } catch (IOException e) {
            log.error("HTTP请求执行异常", e);
            throw new RuntimeException("HTTP请求执行异常， 执行动作" + ruleName, e);
        } finally {
            if (null != client) {
                try {
                    client.close();
                } catch (IOException e) {
                    throw new RuntimeException(e);
                }
            }
        }
    }

    /**
     * 获取token
     *
     * @return
     */
    public String getToken() {
        try {
            String token = redisCache.getCacheObject(HZOMS_TOKEN_KEY);
            if (StringUtils.isNotBlank(token)) {
                return token;
            } else {
                try {
                    synchronized (HZOMS_TOKEN_KEY) {
                        String tokenSec = redisCache.getCacheObject(HZOMS_TOKEN_KEY);
                        if (StringUtils.isNotBlank(tokenSec)) {
                            return tokenSec;
                        }
                        String requestUrl = getRequestUrl(TOKEN_URL);
                        FsSysConfig sysConfig = configUtil.getSysConfig();
                        HashMap headers = new HashMap<>();
                        headers.put("Content-Type", "application/x-www-form-urlencoded");
                        String body = HttpRequest.post(requestUrl)
                                .addHeaders(headers)
                                .form("appkey", sysConfig.getErpHzOMSAppKey())
                                .form("secret", sysConfig.getErpHzOMSAppsecret()).execute().body();
                        JSONObject jsonObject = JSONObject.parseObject(body);
                        if (null != jsonObject && !jsonObject.isEmpty()) {
                            String code = jsonObject.getString("code");
                            if (null != code && "200".equals(code)) {
                                log.info("瀚智OMS getTokenHTTP请求结果::" + jsonObject);
                                JSONObject tokenData = jsonObject.getJSONObject("data");
                                if (null != tokenData && !tokenData.isEmpty()) {
                                    String tokenStr = tokenData.getString("token");
                                    Long expires = tokenData.getLong("expires_in");
                                    long currentTime = System.currentTimeMillis();
                                    //提前过期
                                    int intExact = Math.toIntExact((expires - currentTime - 180000) / 1000);
                                    redisCache.setCacheObject(HZOMS_TOKEN_KEY, tokenStr, (int) intExact, TimeUnit.SECONDS);
                                }
                            }else{
                                log.error("瀚智OMS getTokenHTTP请求失败::" + jsonObject);
                                return "";
                            }
                        }
                    }
                } catch (ArithmeticException e) {
                    System.out.println("时间转换溢出");
                } catch (Exception ex) {
                    ex.printStackTrace();
                    log.error("瀚智OMS获取tokenHTTP请求失败", ex);
                }
                return getToken();
            }
        } catch (Exception ex) {
            log.error("获取token异常", ex);
            return "";
        }
    }

    /**
     * 获取瀚智租户id
     *
     * @return
     */
    public String getItenantid() {
        FsSysConfig sysConfig = configUtil.getSysConfig();
        String erpHzOMSItenantid = sysConfig.getErpHzOMSItenantid();
        return erpHzOMSItenantid;
    }

    /**
     * 根据type获取请求地址
     *
     * @param tpye
     * @return
     */
    public String getRequestUrl(String tpye) {
        FsSysConfig sysConfig = configUtil.getSysConfig();
        String url = "";
        if (TOKEN_URL.equals(tpye)) {
            url = sysConfig.getErpHzOMTokenUrl();
        } else if (EXEC_RULE_URL.equals(tpye)) {
            url = sysConfig.getErpHzOMBaseUrl();
        }
        return url;
    }

}
