package com.fs.erp.dto.wdt;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.Date;

/**
 * ERP WDT 优惠明细DTO，用于封装订单或子订单中的优惠项信息。
 *
 * @author xdd
 * @date 2025-02-27
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ErpWdtDiscountListDTO {

    /**
     * 平台id
     */
    private Integer platformId;

    /**
     * 原始单号 (关联主订单)
     */
    private String tid;

    /**
     * 原始子订单编号 (如果优惠关联特定子单)
     */
    private String oid;

    /**
     * 明细主键, 自动增量
     */
    private Long recId; // btigin 视为 bigint

    /**
     * 优惠类别
     */
    private String type;

    /**
     * 是否优惠券
     * 0: 否, 1: 是 (tinyint 常用表示方式)
     */
    private Integer isBonus;

    /**
     * 创建时间
     * 时间格式：yyyy-MM-dd HH:mm:ss
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date created;

    /**
     * 优惠名称
     */
    private String name;

    /**
     * 优惠详情
     */
    private String detail;

    /**
     * 优惠金额
     */
    private BigDecimal amount;

    /**
     * 平台唯一标识 (例如优惠券码、活动ID等)
     */
    private String sn;
}
