package com.fs.erp.dto.wdt;

import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;

/**
 * ERP旺店通售后子订单信息 DTO
 * <p>
 * 代表退款单中涉及的具体商品行项目。
 * </p>
 *
 * @author xdd
 * @since 2025-02-27
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ErpWdtRefundOrder {

    /**
     * 平台订单子订单编号
     * <p>
     * 平台订单子订单编号（与推送trade_push的oid保持一致，对应旺店通ERP内原始子订单编号）。可推送部分子订单。
     * 必须: 是
     * 类型: varchar(40)
     * </p>
     */
    @JsonProperty("oid")
    private String oid;

    /**
     * 退货货品数量
     * <p>
     * 退货货品数量（如果是type=1 退款 或 2 退款不退货类型，此处代表退款数量）。
     * 必须: 是
     * 类型: decimal(19,4)
     * </p>
     */
    @JsonProperty("num")
    private BigDecimal num;
}
