package com.fs.his.service;

import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSONObject;
import com.fs.common.core.domain.R;
import com.fs.company.param.FsStoreStatisticsParam;
import com.fs.company.vo.FsStorePaymentStatisticsVO;
import com.fs.his.domain.FsStorePayment;
import com.fs.his.param.FsStorePaymentParam;
import com.fs.his.param.WxSendRedPacketParam;
import com.fs.his.vo.FsStorePaymentExcelVO;
import com.fs.his.vo.FsStorePaymentVO;
import me.chanjar.weixin.common.error.WxErrorException;

import javax.servlet.http.HttpServletRequest;

/**
 * 支付明细Service接口
 *
 * @author fs
 * @date 2023-08-11
 */
public interface IFsStorePaymentService
{
    /**
     * 查询支付明细
     *
     * @param paymentId 支付明细主键
     * @return 支付明细
     */
    public FsStorePayment selectFsStorePaymentByPaymentId(Long paymentId);

    /**
     * 查询支付明细列表
     *
     * @param fsStorePayment 支付明细
     * @return 支付明细集合
     */
    public List<FsStorePayment> selectFsStorePaymentList(FsStorePayment fsStorePayment);

    /**
     * 新增支付明细
     *
     * @param fsStorePayment 支付明细
     * @return 结果
     */
    public int insertFsStorePayment(FsStorePayment fsStorePayment);

    /**
     * 修改支付明细
     *
     * @param fsStorePayment 支付明细
     * @return 结果
     */
    public int updateFsStorePayment(FsStorePayment fsStorePayment);

    /**
     * 批量删除支付明细
     *
     * @param paymentIds 需要删除的支付明细主键集合
     * @return 结果
     */
    public int deleteFsStorePaymentByPaymentIds(Long[] paymentIds);

    /**
     * 删除支付明细信息
     *
     * @param paymentId 支付明细主键
     * @return 结果
     */
    public int deleteFsStorePaymentByPaymentId(Long paymentId);

    FsStorePayment selectFsStorePaymentByPaymentCode(String payCode);

    List<FsStorePaymentVO> selectFsStorePaymentListVO(FsStorePaymentParam fsStorePayment);

    FsStorePaymentVO selectFsStorePaymentByPaymentIdVO(Long paymentId);

    List<FsStorePaymentStatisticsVO> selectFsStorePaymentStatisticsList(FsStoreStatisticsParam param);

    List<JSONObject> selectFsStorePaymentCounts(Map<String, Object> toMap);

    Long selectFsStorePaymentCount(int i, Long companyId);

    List<FsStorePaymentExcelVO> selectFsStorePaymentExcelVO(FsStorePaymentParam fsStorePayment);

    String updateFsStorePaymentByDecryptForm(Long paymentId);

    R refundFsStorePayment(Long paymentId);

    R sendRedPacket(WxSendRedPacketParam param);

    R sendRedPacketV3(WxSendRedPacketParam param);

    String transferNotify(String notifyData, HttpServletRequest request);

    Boolean isEntityNull(FsStorePaymentParam fsStorePayment);

    Long selectFsStorePaymentExcelVOCount(FsStorePaymentParam fsStorePayment);

    String v3TransferNotify(String notifyData, HttpServletRequest request);


    R sendRedPacketTest(WxSendRedPacketParam param);

    List<FsStorePaymentVO> selectFsStorePaymentListQueryVO(FsStorePaymentParam fsStorePayment);
}
