package com.fs.his.service.impl;

import java.util.List;

import com.fs.his.param.FsDoctorPriceParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.his.mapper.FsDoctorPriceMapper;
import com.fs.his.domain.FsDoctorPrice;
import com.fs.his.service.IFsDoctorPriceService;

/**
 * 医生价目Service业务层处理
 *
 * @author fs
 * @date 2023-07-31
 */
@Service
public class FsDoctorPriceServiceImpl implements IFsDoctorPriceService
{
    @Autowired
    private FsDoctorPriceMapper fsDoctorPriceMapper;

    /**
     * 查询医生价目
     *
     * @param priceId 医生价目主键
     * @return 医生价目
     */
    @Override
    public FsDoctorPrice selectFsDoctorPriceByPriceId(Long priceId)
    {
        return fsDoctorPriceMapper.selectFsDoctorPriceByPriceId(priceId);
    }

    /**
     * 查询医生价目列表
     *
     * @param fsDoctorPrice 医生价目
     * @return 医生价目
     */
    @Override
    public List<FsDoctorPrice> selectFsDoctorPriceList(FsDoctorPrice fsDoctorPrice)
    {
        return fsDoctorPriceMapper.selectFsDoctorPriceList(fsDoctorPrice);
    }

    /**
     * 新增医生价目
     *
     * @param fsDoctorPrice 医生价目
     * @return 结果
     */
    @Override
    public int insertFsDoctorPrice(FsDoctorPrice fsDoctorPrice)
    {
        return fsDoctorPriceMapper.insertFsDoctorPrice(fsDoctorPrice);
    }

    /**
     * 修改医生价目
     *
     * @param fsDoctorPrice 医生价目
     * @return 结果
     */
    @Override
    public int updateFsDoctorPrice(FsDoctorPrice fsDoctorPrice)
    {
        return fsDoctorPriceMapper.updateFsDoctorPrice(fsDoctorPrice);
    }

    /**
     * 批量删除医生价目
     *
     * @param priceIds 需要删除的医生价目主键
     * @return 结果
     */
    @Override
    public int deleteFsDoctorPriceByPriceIds(Long[] priceIds)
    {
        return fsDoctorPriceMapper.deleteFsDoctorPriceByPriceIds(priceIds);
    }

    /**
     * 删除医生价目信息
     *
     * @param priceId 医生价目主键
     * @return 结果
     */
    @Override
    public int deleteFsDoctorPriceByPriceId(Long priceId)
    {
        return fsDoctorPriceMapper.deleteFsDoctorPriceByPriceId(priceId);
    }

    @Override
    public List<FsDoctorPrice> selectDoctorPriceByDoctorId(Long doctorId) {
        return fsDoctorPriceMapper.selectDoctorPriceByDoctorId(doctorId);
    }

}
