package com.fs.his.service.impl;

import java.util.List;

import com.fs.common.exception.CustomException;
import com.fs.common.utils.DateUtils;
import com.fs.his.vo.OptionsVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.his.mapper.FsFollowTempMapper;
import com.fs.his.domain.FsFollowTemp;
import com.fs.his.service.IFsFollowTempService;

/**
 * 随访模板Service业务层处理
 *
 * @author fs
 * @date 2023-07-14
 */
@Service
public class FsFollowTempServiceImpl implements IFsFollowTempService
{
    @Autowired
    private FsFollowTempMapper fsFollowTempMapper;

    /**
     * 查询随访模板
     *
     * @param tempId 随访模板主键
     * @return 随访模板
     */
    @Override
    public FsFollowTemp selectFsFollowTempByTempId(Long tempId)
    {
        return fsFollowTempMapper.selectFsFollowTempByTempId(tempId);
    }

    /**
     * 查询随访模板列表
     *
     * @param fsFollowTemp 随访模板
     * @return 随访模板
     */
    @Override
    public List<FsFollowTemp> selectFsFollowTempList(FsFollowTemp fsFollowTemp)
    {
        return fsFollowTempMapper.selectFsFollowTempList(fsFollowTemp);
    }

    /**
     * 新增随访模板
     *
     * @param fsFollowTemp 随访模板
     * @return 结果
     */
    @Override
    public int insertFsFollowTemp(FsFollowTemp fsFollowTemp)
    {
        FsFollowTemp  fs =fsFollowTempMapper.selectFsFollowTempByTempName(fsFollowTemp.getName());
        if (fs!=null){
            throw new CustomException("模板名称已存在");
        }
        fsFollowTemp.setCreateTime(DateUtils.getNowDate());
        return fsFollowTempMapper.insertFsFollowTemp(fsFollowTemp);
    }

    /**
     * 修改随访模板
     *
     * @param fsFollowTemp 随访模板
     * @return 结果
     */
    @Override
    public int updateFsFollowTemp(FsFollowTemp fsFollowTemp)
    {
        FsFollowTemp  fs =fsFollowTempMapper.selectFsFollowTempByTempName(fsFollowTemp.getName());
        if (fs!=null&&!fsFollowTemp.getTempId().equals(fs.getTempId())){
            throw new CustomException("模板名称已存在");
        }
        fsFollowTemp.setUpdateTime(DateUtils.getNowDate());
        return fsFollowTempMapper.updateFsFollowTemp(fsFollowTemp);
    }

    /**
     * 批量删除随访模板
     *
     * @param tempIds 需要删除的随访模板主键
     * @return 结果
     */
    @Override
    public int deleteFsFollowTempByTempIds(Long[] tempIds)
    {
        return fsFollowTempMapper.deleteFsFollowTempByTempIds(tempIds);
    }

    /**
     * 删除随访模板信息
     *
     * @param tempId 随访模板主键
     * @return 结果
     */
    @Override
    public int deleteFsFollowTempByTempId(Long tempId)
    {
        return fsFollowTempMapper.deleteFsFollowTempByTempId(tempId);
    }

    @Override
    public List<OptionsVO> selectAllFsFollowTempList() {
        return fsFollowTempMapper.selectAllFsFollowTempList();
    }
}
