package com.fs.his.service.impl;

import java.util.List;

import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.his.mapper.FsInquiryOrderLogsMapper;
import com.fs.his.domain.FsInquiryOrderLogs;
import com.fs.his.service.IFsInquiryOrderLogsService;

/**
 * 订单操作记录Service业务层处理
 *
 * @author fs
 * @date 2023-10-30
 */
@Service
public class FsInquiryOrderLogsServiceImpl implements IFsInquiryOrderLogsService
{
    @Autowired
    private FsInquiryOrderLogsMapper fsInquiryOrderLogsMapper;

    /**
     * 查询订单操作记录
     *
     * @param logsId 订单操作记录主键
     * @return 订单操作记录
     */
    @Override
    public FsInquiryOrderLogs selectFsInquiryOrderLogsByLogsId(Long logsId)
    {
        return fsInquiryOrderLogsMapper.selectFsInquiryOrderLogsByLogsId(logsId);
    }

    /**
     * 查询订单操作记录列表
     *
     * @param fsInquiryOrderLogs 订单操作记录
     * @return 订单操作记录
     */
    @Override
    public List<FsInquiryOrderLogs> selectFsInquiryOrderLogsList(FsInquiryOrderLogs fsInquiryOrderLogs)
    {
        return fsInquiryOrderLogsMapper.selectFsInquiryOrderLogsList(fsInquiryOrderLogs);
    }

    /**
     * 新增订单操作记录
     *
     * @param fsInquiryOrderLogs 订单操作记录
     * @return 结果
     */
    @Override
    public int insertFsInquiryOrderLogs(FsInquiryOrderLogs fsInquiryOrderLogs)
    {
        fsInquiryOrderLogs.setCreateTime(DateUtils.getNowDate());
        return fsInquiryOrderLogsMapper.insertFsInquiryOrderLogs(fsInquiryOrderLogs);
    }

    /**
     * 修改订单操作记录
     *
     * @param fsInquiryOrderLogs 订单操作记录
     * @return 结果
     */
    @Override
    public int updateFsInquiryOrderLogs(FsInquiryOrderLogs fsInquiryOrderLogs)
    {
        return fsInquiryOrderLogsMapper.updateFsInquiryOrderLogs(fsInquiryOrderLogs);
    }

    /**
     * 批量删除订单操作记录
     *
     * @param logsIds 需要删除的订单操作记录主键
     * @return 结果
     */
    @Override
    public int deleteFsInquiryOrderLogsByLogsIds(Long[] logsIds)
    {
        return fsInquiryOrderLogsMapper.deleteFsInquiryOrderLogsByLogsIds(logsIds);
    }

    /**
     * 删除订单操作记录信息
     *
     * @param logsId 订单操作记录主键
     * @return 结果
     */
    @Override
    public int deleteFsInquiryOrderLogsByLogsId(Long logsId)
    {
        return fsInquiryOrderLogsMapper.deleteFsInquiryOrderLogsByLogsId(logsId);
    }
}
