package com.fs.his.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.fs.his.param.FsStoreBillParam;
import com.fs.his.vo.FsStoreBillVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.his.mapper.FsStoreBillMapper;
import com.fs.his.domain.FsStoreBill;
import com.fs.his.service.IFsStoreBillService;

/**
 * 店铺帐单记录Service业务层处理
 *
 * @author fs
 * @date 2023-06-25
 */
@Service
public class FsStoreBillServiceImpl implements IFsStoreBillService
{
    @Autowired
    private FsStoreBillMapper fsStoreBillMapper;

    /**
     * 查询店铺帐单记录
     *
     * @param billId 店铺帐单记录主键
     * @return 店铺帐单记录
     */
    @Override
    public FsStoreBill selectFsStoreBillByBillId(Long billId)
    {
        return fsStoreBillMapper.selectFsStoreBillByBillId(billId);
    }

    /**
     * 查询店铺帐单记录列表
     *
     * @param fsStoreBill 店铺帐单记录
     * @return 店铺帐单记录
     */
    @Override
    public List<FsStoreBill> selectFsStoreBillList(FsStoreBill fsStoreBill)
    {
        return fsStoreBillMapper.selectFsStoreBillList(fsStoreBill);
    }

    /**
     * 新增店铺帐单记录
     *
     * @param fsStoreBill 店铺帐单记录
     * @return 结果
     */
    @Override
    public int insertFsStoreBill(FsStoreBill fsStoreBill)
    {
        fsStoreBill.setCreateTime(DateUtils.getNowDate());
        return fsStoreBillMapper.insertFsStoreBill(fsStoreBill);
    }

    /**
     * 修改店铺帐单记录
     *
     * @param fsStoreBill 店铺帐单记录
     * @return 结果
     */
    @Override
    public int updateFsStoreBill(FsStoreBill fsStoreBill)
    {
        return fsStoreBillMapper.updateFsStoreBill(fsStoreBill);
    }

    /**
     * 批量删除店铺帐单记录
     *
     * @param billIds 需要删除的店铺帐单记录主键
     * @return 结果
     */
    @Override
    public int deleteFsStoreBillByBillIds(Long[] billIds)
    {
        return fsStoreBillMapper.deleteFsStoreBillByBillIds(billIds);
    }

    /**
     * 删除店铺帐单记录信息
     *
     * @param billId 店铺帐单记录主键
     * @return 结果
     */
    @Override
    public int deleteFsStoreBillByBillId(Long billId)
    {
        return fsStoreBillMapper.deleteFsStoreBillByBillId(billId);
    }

    @Override
    public List<FsStoreBillVO> selectFsStoreBillListVO(FsStoreBillParam fsStoreBill) {
        return fsStoreBillMapper.selectFsStoreBillListVO(fsStoreBill);
    }
}
