package com.fs.hospital.mapper;

import java.util.List;

import com.fs.company.domain.CompanyRole;
import com.fs.hospital.domain.HospitalRole;
import org.apache.ibatis.annotations.Select;

/**
 * 角色信息Mapper接口
 *
 * @author fs
 * @date 2024-02-26
 */
public interface HospitalRoleMapper
{
    /**
     * 查询角色信息
     *
     * @param roleId 角色信息主键
     * @return 角色信息
     */
    public HospitalRole selectHospitalRoleByRoleId(Long roleId);

    /**
     * 查询角色信息列表
     *
     * @param hospitalRole 角色信息
     * @return 角色信息集合
     */
    public List<HospitalRole> selectHospitalRoleList(HospitalRole hospitalRole);

    /**
     * 新增角色信息
     *
     * @param hospitalRole 角色信息
     * @return 结果
     */
    public int insertHospitalRole(HospitalRole hospitalRole);

    /**
     * 修改角色信息
     *
     * @param hospitalRole 角色信息
     * @return 结果
     */
    public int updateHospitalRole(HospitalRole hospitalRole);

    /**
     * 删除角色信息
     *
     * @param roleId 角色信息主键
     * @return 结果
     */
    public int deleteHospitalRoleByRoleId(Long roleId);

    /**
     * 批量删除角色信息
     *
     * @param roleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHospitalRoleByRoleIds(Long[] roleIds);

    List<HospitalRole> selectRolePermissionByUserId(Long userId);

    List<Integer> selectRoleListByUserId(Long userId);

    List<HospitalRole> selectRolesByUserName(String username);

    HospitalRole checkRoleNameUnique(String roleName);

    HospitalRole checkRoleKeyUnique(String roleKey);
}
