package com.fs.hospital.service;

import java.util.List;

import com.fs.company.domain.CompanyDeptTreeSelect;
import com.fs.hospital.domain.HospitalDept;
import com.fs.hospital.domain.HospitalDeptTreeSelect;

/**
 * 部门Service接口
 *
 * @author fs
 * @date 2024-02-26
 */
public interface IHospitalDeptService
{
    /**
     * 查询部门
     *
     * @param deptId 部门主键
     * @return 部门
     */
    public HospitalDept selectHospitalDeptByDeptId(Long deptId);

    /**
     * 查询部门列表
     *
     * @param hospitalDept 部门
     * @return 部门集合
     */
    public List<HospitalDept> selectHospitalDeptList(HospitalDept hospitalDept);

    /**
     * 新增部门
     *
     * @param hospitalDept 部门
     * @return 结果
     */
    public int insertHospitalDept(HospitalDept hospitalDept);

    /**
     * 修改部门
     *
     * @param hospitalDept 部门
     * @return 结果
     */
    public int updateHospitalDept(HospitalDept hospitalDept);

    /**
     * 批量删除部门
     *
     * @param deptIds 需要删除的部门主键集合
     * @return 结果
     */
    public int deleteHospitalDeptByDeptIds(Long[] deptIds);

    /**
     * 删除部门信息
     *
     * @param deptId 部门主键
     * @return 结果
     */
    public int deleteHospitalDeptByDeptId(Long deptId);

    List<HospitalDeptTreeSelect> buildDeptTreeSelect(List<HospitalDept> depts);

    public List<HospitalDept> buildDeptTree(List<HospitalDept> depts);



    List<Integer> selectDeptListByRoleId(Long roleId);

    int checkDeptNameUnique(HospitalDept dept);

    int selectNormalChildrenDeptById(Long deptId);

    int checkDeptExistUser(Long deptId);

    int hasChildByDeptId(Long deptId);
}
