package com.fs.hospital.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.hospital.domain.HospitalProductPurchaseOrder;
import com.fs.hospital.param.HospitalProductPurchaseOrderAddEditParam;
import com.fs.hospital.param.HospitalProductPurchaseOrderParam;
import com.fs.hospital.vo.HospitalProductPurchaseOrderHVO;
import com.fs.hospital.vo.HospitalProductPurchaseOrdeHVO;

/**
 * 采购单Service接口
 *
 * @author fs
 * @date 2024-03-12
 */
public interface IHospitalProductPurchaseOrderService
{
    /**
     * 查询采购单
     *
     * @param orderId 采购单主键
     * @return 采购单
     */
    public HospitalProductPurchaseOrder selectHospitalPurchaseOrderByOrderId(Long orderId);

    /**
     * 查询采购单列表
     *
     * @param hospitalProductPurchaseOrder 采购单
     * @return 采购单集合
     */
    public List<HospitalProductPurchaseOrder> selectHospitalPurchaseOrderList(HospitalProductPurchaseOrder hospitalProductPurchaseOrder);

    /**
     * 新增采购单
     *
     * @return 结果
     */
    public R insertHospitalPurchaseOrder(HospitalProductPurchaseOrderAddEditParam param);

    /**
     * 修改采购单
     *
     * @param hospitalProductPurchaseOrder 采购单
     * @return 结果
     */
    public int updateHospitalPurchaseOrder(HospitalProductPurchaseOrder hospitalProductPurchaseOrder);

    /**
     * 批量删除采购单
     *
     * @param orderIds 需要删除的采购单主键集合
     * @return 结果
     */
    public int deleteHospitalPurchaseOrderByOrderIds(Long[] orderIds);

    /**
     * 删除采购单信息
     *
     * @param orderId 采购单主键
     * @return 结果
     */
    public int deleteHospitalPurchaseOrderByOrderId(Long orderId);


    List<HospitalProductPurchaseOrdeHVO> selectHospitalPurchaseOrderListPVO(HospitalProductPurchaseOrderParam param);

    HospitalProductPurchaseOrderHVO selectHospitalPurchaseOrderHVOByOrderId(Long orderId);

    R addSalesOut(HospitalProductPurchaseOrderAddEditParam param);

}
