package com.fs.hospital.service;

import java.util.List;
import com.fs.hospital.domain.HospitalProduct;
import com.fs.hospital.vo.HospitalProductListHVO;

/**
 * 诊所商品Service接口
 *
 * @author fs
 * @date 2024-03-12
 */
public interface IHospitalProductService
{
    /**
     * 查询诊所商品
     *
     * @param productId 诊所商品主键
     * @return 诊所商品
     */
    public HospitalProduct selectHospitalProductByProductId(Long productId);

    /**
     * 查询诊所商品列表
     *
     * @param hospitalProduct 诊所商品
     * @return 诊所商品集合
     */
    public List<HospitalProduct> selectHospitalProductList(HospitalProduct hospitalProduct);

    /**
     * 新增诊所商品
     *
     * @param hospitalProduct 诊所商品
     * @return 结果
     */
    public int insertHospitalProduct(HospitalProduct hospitalProduct);

    /**
     * 修改诊所商品
     *
     * @param hospitalProduct 诊所商品
     * @return 结果
     */
    public int updateHospitalProduct(HospitalProduct hospitalProduct);

    /**
     * 批量删除诊所商品
     *
     * @param productIds 需要删除的诊所商品主键集合
     * @return 结果
     */
    public int deleteHospitalProductByProductIds(Long[] productIds);

    /**
     * 删除诊所商品信息
     *
     * @param productId 诊所商品主键
     * @return 结果
     */
    public int deleteHospitalProductByProductId(Long productId);


    List<HospitalProductListHVO> selectHospitalProductListPVO(HospitalProduct hospitalProduct);
}
