package com.fs.hospital.service;

import java.util.Collection;
import java.util.List;
import com.fs.hospital.domain.HospitalRole;

/**
 * 角色信息Service接口
 *
 * @author fs
 * @date 2024-02-26
 */
public interface IHospitalRoleService
{
    /**
     * 查询角色信息
     *
     * @param roleId 角色信息主键
     * @return 角色信息
     */
    public HospitalRole selectHospitalRoleByRoleId(Long roleId);

    /**
     * 查询角色信息列表
     *
     * @param hospitalRole 角色信息
     * @return 角色信息集合
     */
    public List<HospitalRole> selectHospitalRoleList(HospitalRole hospitalRole);

    /**
     * 新增角色信息
     *
     * @param hospitalRole 角色信息
     * @return 结果
     */
    public int insertHospitalRole(HospitalRole hospitalRole);

    /**
     * 修改角色信息
     *
     * @param hospitalRole 角色信息
     * @return 结果
     */
    public int updateHospitalRole(HospitalRole hospitalRole);

    /**
     * 批量删除角色信息
     *
     * @param roleIds 需要删除的角色信息主键集合
     * @return 结果
     */
    public int deleteHospitalRoleByRoleIds(Long[] roleIds);

    /**
     * 删除角色信息信息
     *
     * @param roleId 角色信息主键
     * @return 结果
     */
    public int deleteHospitalRoleByRoleId(Long roleId);

    Collection<? extends String> selectMenuPermsByUserId(Long userId);

    Collection<? extends String> selectRolePermissionByUserId(Long userId);

    List<Integer> selectRoleListByUserId(Long userId);

    String checkRoleNameUnique(HospitalRole role);

    String checkRoleKeyUnique(HospitalRole role);

    int insertRole(HospitalRole role);

    int updateRole(HospitalRole role);

    int authDataScope(HospitalRole role);

    int updateRoleStatus(HospitalRole role);
}
