package com.fs.hospital.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.hospital.domain.Hospital;
import com.fs.hospital.param.HospitalParam;
import com.fs.hospital.vo.HospitalHVO;

/**
 * 诊所Service接口
 *
 * @author fs
 * @date 2024-02-26
 */
public interface IHospitalService
{
    /**
     * 查询诊所
     *
     * @param hospitalId 诊所主键
     * @return 诊所
     */
    public Hospital selectHospitalByHospitalId(Long hospitalId);

    /**
     * 查询诊所列表
     *
     * @param hospital 诊所
     * @return 诊所集合
     */
    public List<Hospital> selectHospitalList(Hospital hospital);

    /**
     * 新增诊所
     *
     * @param hospital 诊所
     * @return 结果
     */
//    public int insertHospital(Hospital hospital);

    /**
     * 修改诊所
     *
     * @param hospital 诊所
     * @return 结果
     */
    public int updateHospital(Hospital hospital);

    /**
     * 批量删除诊所
     *
     * @param hospitalIds 需要删除的诊所主键集合
     * @return 结果
     */
    public int deleteHospitalByHospitalIds(Long[] hospitalIds);

    /**
     * 删除诊所信息
     *
     * @param hospitalId 诊所主键
     * @return 结果
     */
    public int deleteHospitalByHospitalId(Long hospitalId);

    List<HospitalHVO> selectHospitalListVO(HospitalParam param);

    R insertHospital(Hospital hospital);
}
