package com.fs.hospital.service;

import java.util.List;
import com.fs.hospital.domain.HospitalStore;
import com.fs.hospital.param.HospitalStoreParam;
import com.fs.hospital.vo.HospitalStoreHVO;

/**
 * 诊所供应商关联Service接口
 *
 * @author fs
 * @date 2024-03-12
 */
public interface IHospitalStoreService
{
    /**
     * 查询诊所供应商关联
     *
     * @param id 诊所供应商关联主键
     * @return 诊所供应商关联
     */
    public HospitalStore selectHospitalStoreById(Long id);

    /**
     * 查询诊所供应商关联列表
     *
     * @param hospitalStore 诊所供应商关联
     * @return 诊所供应商关联集合
     */
    public List<HospitalStore> selectHospitalStoreList(HospitalStore hospitalStore);

    /**
     * 新增诊所供应商关联
     *
     * @param hospitalStore 诊所供应商关联
     * @return 结果
     */
    public int insertHospitalStore(HospitalStore hospitalStore);

    /**
     * 修改诊所供应商关联
     *
     * @param hospitalStore 诊所供应商关联
     * @return 结果
     */
    public int updateHospitalStore(HospitalStore hospitalStore);

    /**
     * 批量删除诊所供应商关联
     *
     * @param ids 需要删除的诊所供应商关联主键集合
     * @return 结果
     */
    public int deleteHospitalStoreByIds(Long[] ids);

    /**
     * 删除诊所供应商关联信息
     *
     * @param id 诊所供应商关联主键
     * @return 结果
     */
    public int deleteHospitalStoreById(Long id);


    List<HospitalStoreHVO> selectHospitalStoreListPVO(HospitalStoreParam param);
}
