package com.fs.hospital.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.hospital.mapper.HospitalOperLogMapper;
import com.fs.hospital.domain.HospitalOperLog;
import com.fs.hospital.service.IHospitalOperLogService;

/**
 * 操作日志记录Service业务层处理
 * 
 * @author fs
 * @date 2024-02-27
 */
@Service
public class HospitalOperLogServiceImpl implements IHospitalOperLogService 
{
    @Autowired
    private HospitalOperLogMapper hospitalOperLogMapper;

    /**
     * 查询操作日志记录
     * 
     * @param operId 操作日志记录主键
     * @return 操作日志记录
     */
    @Override
    public HospitalOperLog selectHospitalOperLogByOperId(Long operId)
    {
        return hospitalOperLogMapper.selectHospitalOperLogByOperId(operId);
    }

    /**
     * 查询操作日志记录列表
     * 
     * @param hospitalOperLog 操作日志记录
     * @return 操作日志记录
     */
    @Override
    public List<HospitalOperLog> selectHospitalOperLogList(HospitalOperLog hospitalOperLog)
    {
        return hospitalOperLogMapper.selectHospitalOperLogList(hospitalOperLog);
    }

    /**
     * 新增操作日志记录
     * 
     * @param hospitalOperLog 操作日志记录
     * @return 结果
     */
    @Override
    public int insertHospitalOperLog(HospitalOperLog hospitalOperLog)
    {
        return hospitalOperLogMapper.insertHospitalOperLog(hospitalOperLog);
    }

    /**
     * 修改操作日志记录
     * 
     * @param hospitalOperLog 操作日志记录
     * @return 结果
     */
    @Override
    public int updateHospitalOperLog(HospitalOperLog hospitalOperLog)
    {
        return hospitalOperLogMapper.updateHospitalOperLog(hospitalOperLog);
    }

    /**
     * 批量删除操作日志记录
     * 
     * @param operIds 需要删除的操作日志记录主键
     * @return 结果
     */
    @Override
    public int deleteHospitalOperLogByOperIds(Long[] operIds)
    {
        return hospitalOperLogMapper.deleteHospitalOperLogByOperIds(operIds);
    }

    /**
     * 删除操作日志记录信息
     * 
     * @param operId 操作日志记录主键
     * @return 结果
     */
    @Override
    public int deleteHospitalOperLogByOperId(Long operId)
    {
        return hospitalOperLogMapper.deleteHospitalOperLogByOperId(operId);
    }
}
