package com.fs.hospital.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.hospital.mapper.HospitalRoleDeptMapper;
import com.fs.hospital.domain.HospitalRoleDept;
import com.fs.hospital.service.IHospitalRoleDeptService;

/**
 * 角色和部门关联Service业务层处理
 * 
 * @author fs
 * @date 2024-02-26
 */
@Service
public class HospitalRoleDeptServiceImpl implements IHospitalRoleDeptService 
{
    @Autowired
    private HospitalRoleDeptMapper hospitalRoleDeptMapper;

    /**
     * 查询角色和部门关联
     * 
     * @param roleId 角色和部门关联主键
     * @return 角色和部门关联
     */
    @Override
    public HospitalRoleDept selectHospitalRoleDeptByRoleId(Long roleId)
    {
        return hospitalRoleDeptMapper.selectHospitalRoleDeptByRoleId(roleId);
    }

    /**
     * 查询角色和部门关联列表
     * 
     * @param hospitalRoleDept 角色和部门关联
     * @return 角色和部门关联
     */
    @Override
    public List<HospitalRoleDept> selectHospitalRoleDeptList(HospitalRoleDept hospitalRoleDept)
    {
        return hospitalRoleDeptMapper.selectHospitalRoleDeptList(hospitalRoleDept);
    }

    /**
     * 新增角色和部门关联
     * 
     * @param hospitalRoleDept 角色和部门关联
     * @return 结果
     */
    @Override
    public int insertHospitalRoleDept(HospitalRoleDept hospitalRoleDept)
    {
        return hospitalRoleDeptMapper.insertHospitalRoleDept(hospitalRoleDept);
    }

    /**
     * 修改角色和部门关联
     * 
     * @param hospitalRoleDept 角色和部门关联
     * @return 结果
     */
    @Override
    public int updateHospitalRoleDept(HospitalRoleDept hospitalRoleDept)
    {
        return hospitalRoleDeptMapper.updateHospitalRoleDept(hospitalRoleDept);
    }

    /**
     * 批量删除角色和部门关联
     * 
     * @param roleIds 需要删除的角色和部门关联主键
     * @return 结果
     */
    @Override
    public int deleteHospitalRoleDeptByRoleIds(Long[] roleIds)
    {
        return hospitalRoleDeptMapper.deleteHospitalRoleDeptByRoleIds(roleIds);
    }

    /**
     * 删除角色和部门关联信息
     * 
     * @param roleId 角色和部门关联主键
     * @return 结果
     */
    @Override
    public int deleteHospitalRoleDeptByRoleId(Long roleId)
    {
        return hospitalRoleDeptMapper.deleteHospitalRoleDeptByRoleId(roleId);
    }
}
