package com.fs.hospital.service.impl;

import java.util.List;

import com.fs.common.exception.CustomException;
import com.fs.hospital.domain.HospitalInspectItem;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.hospital.mapper.HospitalTreatItemMapper;
import com.fs.hospital.domain.HospitalTreatItem;
import com.fs.hospital.service.IHospitalTreatItemService;

/**
 * 治疗Service业务层处理
 *
 * @author fs
 * @date 2024-03-26
 */
@Service
public class HospitalTreatItemServiceImpl implements IHospitalTreatItemService
{
    @Autowired
    private HospitalTreatItemMapper hospitalTreatItemMapper;

    /**
     * 查询治疗
     *
     * @param treatId 治疗主键
     * @return 治疗
     */
    @Override
    public HospitalTreatItem selectHospitalTreatItemByTreatId(Long treatId)
    {
        return hospitalTreatItemMapper.selectHospitalTreatItemByTreatId(treatId);
    }

    /**
     * 查询治疗列表
     *
     * @param hospitalTreatItem 治疗
     * @return 治疗
     */
    @Override
    public List<HospitalTreatItem> selectHospitalTreatItemList(HospitalTreatItem hospitalTreatItem)
    {
        return hospitalTreatItemMapper.selectHospitalTreatItemList(hospitalTreatItem);
    }

    /**
     * 新增治疗
     *
     * @param hospitalTreatItem 治疗
     * @return 结果
     */
    @Override
    public int insertHospitalTreatItem(HospitalTreatItem hospitalTreatItem)
    {
        HospitalTreatItem item = hospitalTreatItemMapper.selectHospitalTreatItemBycode(hospitalTreatItem.getTreatCode());
        if (item!=null){
            throw new CustomException("已经存在该编号");
        }
        return hospitalTreatItemMapper.insertHospitalTreatItem(hospitalTreatItem);
    }

    /**
     * 修改治疗
     *
     * @param hospitalTreatItem 治疗
     * @return 结果
     */
    @Override
    public int updateHospitalTreatItem(HospitalTreatItem hospitalTreatItem)
    {
        HospitalTreatItem item = hospitalTreatItemMapper.selectHospitalTreatItemBycode(hospitalTreatItem.getTreatCode());
        if (item!=null&&item.getTreatId()!=hospitalTreatItem.getTreatId()){
            throw new CustomException("已经存在该编号");
        }
        return hospitalTreatItemMapper.updateHospitalTreatItem(hospitalTreatItem);
    }

    /**
     * 批量删除治疗
     *
     * @param treatIds 需要删除的治疗主键
     * @return 结果
     */
    @Override
    public int deleteHospitalTreatItemByTreatIds(Long[] treatIds)
    {
        return hospitalTreatItemMapper.deleteHospitalTreatItemByTreatIds(treatIds);
    }

    /**
     * 删除治疗信息
     *
     * @param treatId 治疗主键
     * @return 结果
     */
    @Override
    public int deleteHospitalTreatItemByTreatId(Long treatId)
    {
        return hospitalTreatItemMapper.deleteHospitalTreatItemByTreatId(treatId);
    }
}
