package com.fs.qw.domain;

import com.fs.common.annotation.Excel;
import com.fs.common.core.domain.BaseEntity;
import lombok.Data;

/**
 * 入群欢迎语管理对象 qw_welcome
 *
 * @author fs
 * @date 2024-06-22
 */
@Data
public class QwWelcome extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 入群欢迎语id */
    private Long welcomeId;

    /** 欢迎语素材id（最多存100条，包含企微后台添加的） */
    @Excel(name = "欢迎语素材id", readConverterExp = "最=多存100条，包含企微后台添加的")
    private String templateId;

    /** 欢迎语类型   1文本+图片 2图片 3文本+小程序  4文本+文件 3文本+视频 */
    @Excel(name = "欢迎语类型  1文本+图片 2图片 3文本+小程序  4文本+文件 3文本+视频")
    private Integer welcomeType;

    /** 消息文本内容 */
    @Excel(name = "消息文本内容")
    private String textContent;

    /** 图片的media_id可以通过素材管理接口获得 */
    @Excel(name = "图片的media_id可以通过素材管理接口获得")
    private String imageMediaId;

    /** 图片的链接，仅可使用上传图片接口得到的链接 */
    @Excel(name = "图片的链接，仅可使用上传图片接口得到的链接")
    private String imagePicUrl;

    /** 图文消息标题，最长为128字节 */
    @Excel(name = "图文消息标题，最长为128字节")
    private String linkTitle;

    /** 图文消息封面的url */
    @Excel(name = "图文消息封面的url")
    private String linkPicurl;

    /** 图文消息的描述，最长为512字节 */
    @Excel(name = "图文消息的描述，最长为512字节")
    private String linkDesc;

    /** 图文消息的链接 */
    @Excel(name = "图文消息的链接")
    private String linkUrl;

    /** 小程序消息标题，最长为64字节 */
    @Excel(name = "小程序消息标题，最长为64字节")
    private String miniprogramTitle;

    /** 小程序消息封面的mediaid，封面图建议尺寸为520*416 */
    @Excel(name = "小程序消息封面的mediaid，封面图建议尺寸为520*416")
    private String miniprogramPicMediaId;

    /** 小程序封面地址 */
    @Excel(name = "小程序封面地址")
    private String miniprogramPicUrl;

    /** 小程序appid，必须是关联到企业的小程序应用 */
    @Excel(name = "小程序appid，必须是关联到企业的小程序应用")
    private String miniprogramAppid;

    /** 小程序page路径 */
    @Excel(name = "小程序page路径")
    private String miniprogramPage;

    /** 文件id，可以通过素材管理、异步上传临时素材接口获得 */
    @Excel(name = "文件id，可以通过素材管理、异步上传临时素材接口获得")
    private String fileMediaId;

    /** 视频媒体文件id，可以通过素材管理、异步上传临时素材接口获得 */
    @Excel(name = "视频媒体文件id，可以通过素材管理、异步上传临时素材接口获得")
    private String videoMediaId;

    /** 文件地址 */
    @Excel(name = "文件地址")
    private String fileUrl;

    /** 是否通知成员将这条入群欢迎语应用到客户群中，0-不通知，1-通知， 不填则通知 */
    @Excel(name = "是否通知成员将这条入群欢迎语应用到客户群中，0-不通知，1-通知， 不填则通知")
    private Integer notify;

    /** 企微的企业id */
    @Excel(name = "企微的企业id")
    private String corpId;

    /** 视频地址 */
    @Excel(name = "视频地址")
    private String videoUrl;

    /** 公司id */
    @Excel(name = "公司id")
    private Long companyId;

    /** 创建人 */
    @Excel(name = "创建人")
    private String createName;

    private String createdAt;
}
