package com.fs.qw.service;

import com.fs.common.core.domain.R;
import com.fs.qw.domain.QwGroupMsg;
import com.fs.qw.param.QwGroupMsgDetailsParam;
import com.fs.qw.param.QwGroupMsgParam;
import com.fs.qw.vo.QwGroupMsgDetailsVO;
import com.fs.qw.vo.QwGroupMsgVO;

import java.util.List;

/**
 * 客户群发记录主Service接口
 *
 * @author fs
 * @date 2024-06-20
 */
public interface IQwGroupMsgService
{
    /**
     * 查询客户群发记录主
     *
     * @param id 客户群发记录主主键
     * @return 客户群发记录主
     */
    public QwGroupMsgVO selectQwGroupMsgByIdVO(Long id);

    /**
     * 查询客户群发记录主列表
     *
     * @param qwGroupMsg 客户群发记录主
     * @return 客户群发记录主集合
     */
    public List<QwGroupMsgVO> selectQwGroupMsgListVO(QwGroupMsg qwGroupMsg);
    public List<QwGroupMsgVO> selectQwGroupMsgListMyVO(QwGroupMsg qwGroupMsg);

    /**
     * 新增客户群发/客户群群发记录
     *
     * @param qwGroupMsgParam 客户群发记录参数
     * @return 结果
     */
    public R insertQwGroupMsg(QwGroupMsgParam qwGroupMsgParam) throws Exception;

    /** 统计数据详情，已发送，未发送，已接收，未接收等 */
    public R getCountGroupMsgUser(Long groupMsgId);

    /** 统计数据详情，已发送群主，送达群聊，未发送群主，未送达群聊等 */
    public R getCountGroupMsgBaseUser(Long groupMsgId);


    /**
     *  客户群发 发送/接收的数据详情
     */
    public List<QwGroupMsgDetailsVO> getCountGroupMsgUserDetails(QwGroupMsgDetailsParam qwGroupMsgDetailsParam);

    /** 提醒成员群发 */
    public R remindGroupMsg(QwGroupMsgDetailsParam qwGroupMsgDetailsParam);
    /**
     * 修改客户群发记录主
     *
     * @param qwGroupMsg 客户群发记录主
     * @return 结果
     */
    public int updateQwGroupMsg(QwGroupMsg qwGroupMsg);

    /**
     * 批量删除客户群发记录主
     *
     * @param ids 需要删除的客户群发记录主主键集合
     * @return 结果
     */
    public int deleteQwGroupMsgByIds(Long[] ids);

    /**
     * 删除客户群发记录主信息
     *
     * @param id 客户群发记录主主键
     * @return 结果
     */
    public int deleteQwGroupMsgById(Long id);

    /**
    * 定时群发功能-定时任务
    */
    public void qwGroupMsgTask();
}
