package com.fs.qw.service;

import com.fs.qw.domain.QwTag;
import com.fs.qw.domain.QwUser;
import com.fs.qw.param.QwTagParam;
import com.fs.qw.param.QwTagSearchParam;
import com.fs.qw.param.newparam.ContactTagListParam;
import com.fs.qw.vo.QwTagGroupListVO;
import com.fs.qw.vo.QwTagVO;

import java.util.List;

/**
 * 企微客户标签Service接口
 *
 * @author fs
 * @date 2024-06-20
 */
public interface IQwTagService
{
    /**
     * 查询企微客户标签
     *
     * @param id 企微客户标签主键
     * @return 企微客户标签
     */
    public QwTag selectQwTagById(Long id);

    /**
     * 查询企微客户标签列表
     *
     * @param qwTag 企微客户标签
     * @return 企微客户标签集合
     */
    public List<QwTag> selectQwTagList(QwTag qwTag);
    public List<QwTagGroupListVO> searchTags(QwTagParam tagParam);

    /**
     * 新增企微客户标签
     *
     * @param qwTag 企微客户标签
     * @return 结果
     */
    public int insertQwTag(QwTag qwTag);

    /**
     * 修改企微客户标签
     *
     * @param qwTag 企微客户标签
     * @return 结果
     */
    public int updateQwTag(QwTag qwTag);

    /**
     * 批量删除企微客户标签
     *
     * @param ids 需要删除的企微客户标签主键集合
     * @return 结果
     */
    public int deleteQwTagByIds(Long[] ids);

    /**
     * 删除企微客户标签信息
     *
     * @param id 企微客户标签主键
     * @return 结果
     */
    public int deleteQwTagById(Long id);

    void AddCourseTag(QwUser user);

    public List<String> selectQwTagListByTagIds(QwTagSearchParam param);

    List<QwTagVO> getTagListByUserId(ContactTagListParam param);
}
