package com.fs.qw.service.impl;

import com.fs.qw.domain.QwAutoTagsLogs;
import com.fs.qw.mapper.QwAutoTagsLogsMapper;
import com.fs.qw.param.QwAutoTagsLogsParams;
import com.fs.qw.service.IQwAutoTagsLogsService;
import com.fs.qw.vo.QwAutoTagsLogsVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 自动打标签的日志Service业务层处理
 * 
 * @author fs
 * @date 2024-07-20
 */
@Service
public class QwAutoTagsLogsServiceImpl implements IQwAutoTagsLogsService 
{
    @Autowired
    private QwAutoTagsLogsMapper qwAutoTagsLogsMapper;

    /**
     * 查询自动打标签的日志
     * 
     * @param id 自动打标签的日志主键
     * @return 自动打标签的日志
     */
    @Override
    public QwAutoTagsLogs selectQwAutoTagsLogsById(Long id)
    {
        return qwAutoTagsLogsMapper.selectQwAutoTagsLogsById(id);
    }

    /**
     * 查询自动打标签的日志列表
     * 
     * @param qwAutoTagsLogs 自动打标签的日志
     * @return 自动打标签的日志
     */
    @Override
    public List<QwAutoTagsLogs> selectQwAutoTagsLogsList(QwAutoTagsLogs qwAutoTagsLogs)
    {
        return qwAutoTagsLogsMapper.selectQwAutoTagsLogsList(qwAutoTagsLogs);
    }

    @Override
    public List<QwAutoTagsLogsVO> selectQwAutoTagsLogsListVO(QwAutoTagsLogsParams params) {

        return qwAutoTagsLogsMapper.selectQwAutoTagsLogsListVO(params);
    }

    /**
     * 新增自动打标签的日志
     * 
     * @param qwAutoTagsLogs 自动打标签的日志
     * @return 结果
     */
    @Override
    public int insertQwAutoTagsLogs(QwAutoTagsLogs qwAutoTagsLogs)
    {
        return qwAutoTagsLogsMapper.insertQwAutoTagsLogs(qwAutoTagsLogs);
    }

    /**
     * 修改自动打标签的日志
     * 
     * @param qwAutoTagsLogs 自动打标签的日志
     * @return 结果
     */
    @Override
    public int updateQwAutoTagsLogs(QwAutoTagsLogs qwAutoTagsLogs)
    {
        return qwAutoTagsLogsMapper.updateQwAutoTagsLogs(qwAutoTagsLogs);
    }

    /**
     * 批量删除自动打标签的日志
     * 
     * @param ids 需要删除的自动打标签的日志主键
     * @return 结果
     */
    @Override
    public int deleteQwAutoTagsLogsByIds(Long[] ids)
    {
        return qwAutoTagsLogsMapper.deleteQwAutoTagsLogsByIds(ids);
    }

    /**
     * 删除自动打标签的日志信息
     * 
     * @param id 自动打标签的日志主键
     * @return 结果
     */
    @Override
    public int deleteQwAutoTagsLogsById(Long id)
    {
        return qwAutoTagsLogsMapper.deleteQwAutoTagsLogsById(id);
    }
}
