package com.fs.qw.service.impl;

import com.fs.common.exception.CustomException;
import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwContactBatch;
import com.fs.qw.domain.QwUser;
import com.fs.qw.mapper.QwContactBatchMapper;
import com.fs.qw.mapper.QwUserMapper;
import com.fs.qw.service.IQwContactBatchService;
import com.fs.qw.vo.QwContactBatchListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 企微公海Service业务层处理
 *
 * @author fs
 * @date 2024-07-12
 */
@Service
public class QwContactBatchServiceImpl implements IQwContactBatchService
{
    @Autowired
    private QwContactBatchMapper qwContactBatchMapper;
    @Autowired
    private QwUserMapper qwUserMapper;
    /**
     * 查询企微公海
     *
     * @param id 企微公海主键
     * @return 企微公海
     */
    @Override
    public QwContactBatch selectQwContactBatchById(Long id)
    {
        return qwContactBatchMapper.selectQwContactBatchById(id);
    }

    @Override
    public QwContactBatchListVO selectQwContactBatchByIdVO(Long id) {
        return qwContactBatchMapper.selectQwContactBatchByIdVO(id);
    }

    /**
     * 查询企微公海列表
     *
     * @param qwContactBatch 企微公海
     * @return 企微公海
     */
    @Override
    public List<QwContactBatch> selectQwContactBatchList(QwContactBatch qwContactBatch)
    {
        return qwContactBatchMapper.selectQwContactBatchList(qwContactBatch);
    }

    /**
     * 新增企微公海
     *
     * @param qwContactBatch 企微公海
     * @return 结果
     */
    @Override
    public int insertQwContactBatch(QwContactBatch qwContactBatch)
    {

        Long qwUserId = qwContactBatch.getQwUserId();
        if (qwUserId!=null){
            QwUser qwUser = qwUserMapper.selectQwUserById(qwUserId);
            if (qwUser!=null){
                qwContactBatch.setCompanyUserId(qwUser.getCompanyUserId());
            }else {
                throw  new CustomException("查无此人");
            }
        }
        qwContactBatch.setNum(0);
        qwContactBatch.setCreateTime(new Date());
        qwContactBatch.setCreateTime(DateUtils.getNowDate());
        return qwContactBatchMapper.insertQwContactBatch(qwContactBatch);
    }

    /**
     * 修改企微公海
     *
     * @param qwContactBatch 企微公海
     * @return 结果
     */
    @Override
    public int updateQwContactBatch(QwContactBatch qwContactBatch)
    {
        Long qwUserId = qwContactBatch.getQwUserId();
        if (qwUserId!=null){
            QwUser qwUser = qwUserMapper.selectQwUserById(qwUserId);
            if (qwUser!=null){
                qwContactBatch.setCompanyUserId(qwUser.getCompanyUserId());
            }else {
                throw  new CustomException("查无此人");
            }
        }
        return qwContactBatchMapper.updateQwContactBatch(qwContactBatch);
    }

    /**
     * 批量删除企微公海
     *
     * @param ids 需要删除的企微公海主键
     * @return 结果
     */
    @Override
    public int deleteQwContactBatchByIds(Long[] ids)
    {
        return qwContactBatchMapper.deleteQwContactBatchByIds(ids);
    }

    /**
     * 删除企微公海信息
     *
     * @param id 企微公海主键
     * @return 结果
     */
    @Override
    public int deleteQwContactBatchById(Long id)
    {
        return qwContactBatchMapper.deleteQwContactBatchById(id);
    }

    @Override
    public List<QwContactBatchListVO> selectQwContactBatchListVO(QwContactBatch qwContactBatch) {

        return  qwContactBatchMapper.selectQwContactBatchListVO(qwContactBatch);
    }
}
