package com.fs.qw.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwDrainageLinkLogs;
import com.fs.qw.mapper.QwDrainageLinkLogsMapper;
import com.fs.qw.service.IQwDrainageLinkLogsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 链接日志Service业务层处理
 * 
 * @author fs
 * @date 2024-07-29
 */
@Service
public class QwDrainageLinkLogsServiceImpl implements IQwDrainageLinkLogsService 
{
    @Autowired
    private QwDrainageLinkLogsMapper qwDrainageLinkLogsMapper;

    /**
     * 查询链接日志
     * 
     * @param id 链接日志主键
     * @return 链接日志
     */
    @Override
    public QwDrainageLinkLogs selectQwDrainageLinkLogsById(Long id)
    {
        return qwDrainageLinkLogsMapper.selectQwDrainageLinkLogsById(id);
    }

    /**
     * 查询链接日志列表
     * 
     * @param qwDrainageLinkLogs 链接日志
     * @return 链接日志
     */
    @Override
    public List<QwDrainageLinkLogs> selectQwDrainageLinkLogsList(QwDrainageLinkLogs qwDrainageLinkLogs)
    {
        return qwDrainageLinkLogsMapper.selectQwDrainageLinkLogsList(qwDrainageLinkLogs);
    }

    /**
     * 新增链接日志
     * 
     * @param qwDrainageLinkLogs 链接日志
     * @return 结果
     */
    @Override
    public int insertQwDrainageLinkLogs(QwDrainageLinkLogs qwDrainageLinkLogs)
    {
        qwDrainageLinkLogs.setCreateTime(DateUtils.getNowDate());
        return qwDrainageLinkLogsMapper.insertQwDrainageLinkLogs(qwDrainageLinkLogs);
    }

    /**
     * 修改链接日志
     * 
     * @param qwDrainageLinkLogs 链接日志
     * @return 结果
     */
    @Override
    public int updateQwDrainageLinkLogs(QwDrainageLinkLogs qwDrainageLinkLogs)
    {
        return qwDrainageLinkLogsMapper.updateQwDrainageLinkLogs(qwDrainageLinkLogs);
    }

    /**
     * 批量删除链接日志
     * 
     * @param ids 需要删除的链接日志主键
     * @return 结果
     */
    @Override
    public int deleteQwDrainageLinkLogsByIds(Long[] ids)
    {
        return qwDrainageLinkLogsMapper.deleteQwDrainageLinkLogsByIds(ids);
    }

    /**
     * 删除链接日志信息
     * 
     * @param id 链接日志主键
     * @return 结果
     */
    @Override
    public int deleteQwDrainageLinkLogsById(Long id)
    {
        return qwDrainageLinkLogsMapper.deleteQwDrainageLinkLogsById(id);
    }
}
