package com.fs.qw.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwExternalContactInfo;
import com.fs.qw.mapper.QwExternalContactInfoMapper;
import com.fs.qw.mapper.QwExternalContactMapper;
import com.fs.qw.service.IQwExternalContactInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 外部联系人信息表Service业务层处理
 *
 * @author fs
 * @date 2024-11-22
 */
@Service
public class QwExternalContactInfoServiceImpl implements IQwExternalContactInfoService
{
    @Autowired
    private QwExternalContactInfoMapper qwExternalContactInfoMapper;
    @Autowired
    QwExternalContactMapper qwExternalContactMapper;
    /**
     * 查询外部联系人信息表
     *
     * @param id 外部联系人信息表主键
     * @return 外部联系人信息表
     */
    @Override
    public QwExternalContactInfo selectQwExternalContactInfoById(Long id)
    {
        return qwExternalContactInfoMapper.selectQwExternalContactInfoById(id);
    }

    /**
     * 查询外部联系人信息表列表
     *
     * @param qwExternalContactInfo 外部联系人信息表
     * @return 外部联系人信息表
     */
    @Override
    public List<QwExternalContactInfo> selectQwExternalContactInfoList(QwExternalContactInfo qwExternalContactInfo)
    {
        return qwExternalContactInfoMapper.selectQwExternalContactInfoList(qwExternalContactInfo);
    }

    /**
     * 新增外部联系人信息表
     *
     * @param qwExternalContactInfo 外部联系人信息表
     * @return 结果
     */
    @Override
    public int insertQwExternalContactInfo(QwExternalContactInfo qwExternalContactInfo)
    {
        qwExternalContactInfo.setCreateTime(DateUtils.getNowDate());
        return qwExternalContactInfoMapper.insertQwExternalContactInfo(qwExternalContactInfo);
    }

    /**
     * 修改外部联系人信息表
     *
     * @param qwExternalContactInfo 外部联系人信息表
     * @return 结果
     */
    @Override
    public int updateQwExternalContactInfo(QwExternalContactInfo qwExternalContactInfo)
    {
        qwExternalContactInfo.setUpdateTime(DateUtils.getNowDate());
        return qwExternalContactInfoMapper.updateQwExternalContactInfo(qwExternalContactInfo);
    }

    /**
     * 批量删除外部联系人信息表
     *
     * @param ids 需要删除的外部联系人信息表主键
     * @return 结果
     */
    @Override
    public int deleteQwExternalContactInfoByIds(Long[] ids)
    {
        return qwExternalContactInfoMapper.deleteQwExternalContactInfoByIds(ids);
    }

    /**
     * 删除外部联系人信息表信息
     *
     * @param id 外部联系人信息表主键
     * @return 结果
     */
    @Override
    public int deleteQwExternalContactInfoById(Long id)
    {
        return qwExternalContactInfoMapper.deleteQwExternalContactInfoById(id);
    }

    @Override
    public QwExternalContactInfo selectQwExternalContactInfoByExternalContactId(Long id) {
        return qwExternalContactInfoMapper.selectQwExternalContactInfoByExternalContactId(id);
    }

    @Override
    public int updateQwExternalContactInfoByIds(Long[] ids) {
        for (Long id : ids) {
            qwExternalContactInfoMapper.updateQwExternalContactInfoByExtId(id);
        }
        return 1;
    }
    @Async
    @Override
    public void updateQwExternalContactInfoBytalk(String talkType, Long externalId) {
        QwExternalContactInfo info = qwExternalContactInfoMapper.selectQwExternalContactInfoByExternalContactId(externalId);
        QwExternalContactInfo in = new QwExternalContactInfo();
        in.setTalk(talkType);
        in.setExternalContactId(externalId);
        if (info==null){
            in.setCreateTime(new Date());
            qwExternalContactInfoMapper.insertQwExternalContactInfo(in);
          }else {
            in.setId(info.getId());
            qwExternalContactInfoMapper.updateQwExternalContactInfo(in);
        }
    }

    @Override
    public int updateQwExternalContactInfoByQwUserId(Long qwUserId) {
        List<Long> qwExternalContactsIds = qwExternalContactMapper.selectExternalUserByQwUserId(qwUserId);
        for (Long id : qwExternalContactsIds) {
            qwExternalContactInfoMapper.updateQwExternalContactInfoByExtId(id);
        }

        return 1;
    }

    @Override
    public void updateQwExternalContactInfoByExternalContactId(QwExternalContactInfo qwExternalContactInfo) {
        qwExternalContactInfoMapper.updateQwExternalContactInfoByExternalContactId(qwExternalContactInfo);
    }
}
