package com.fs.qw.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwFriendCircle;
import com.fs.qw.mapper.QwFriendCircleMapper;
import com.fs.qw.service.IQwFriendCircleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 客户朋友圈Service业务层处理
 * 
 * @author fs
 * @date 2024-09-18
 */
@Service
public class QwFriendCircleServiceImpl implements IQwFriendCircleService
{
    @Autowired
    private QwFriendCircleMapper qwFriendCircleMapper;

    /**
     * 查询客户朋友圈
     * 
     * @param id 客户朋友圈主键
     * @return 客户朋友圈
     */
    @Override
    public QwFriendCircle selectQwFriendCircleById(Long id)
    {
        return qwFriendCircleMapper.selectQwFriendCircleById(id);
    }

    /**
     * 查询客户朋友圈列表
     * 
     * @param qwFriendCircle 客户朋友圈
     * @return 客户朋友圈
     */
    @Override
    public List<QwFriendCircle> selectQwFriendCircleList(QwFriendCircle qwFriendCircle)
    {
        return qwFriendCircleMapper.selectQwFriendCircleList(qwFriendCircle);
    }

    /**
     * 新增客户朋友圈
     * 
     * @param qwFriendCircle 客户朋友圈
     * @return 结果
     */
    @Override
    public int insertQwFriendCircle(QwFriendCircle qwFriendCircle)
    {
        qwFriendCircle.setCreateTime(DateUtils.getNowDate());
        return qwFriendCircleMapper.insertQwFriendCircle(qwFriendCircle);
    }

    /**
     * 修改客户朋友圈
     * 
     * @param qwFriendCircle 客户朋友圈
     * @return 结果
     */
    @Override
    public int updateQwFriendCircle(QwFriendCircle qwFriendCircle)
    {
        return qwFriendCircleMapper.updateQwFriendCircle(qwFriendCircle);
    }

    /**
     * 批量删除客户朋友圈
     * 
     * @param ids 需要删除的客户朋友圈主键
     * @return 结果
     */
    @Override
    public int deleteQwFriendCircleByIds(Long[] ids)
    {
        return qwFriendCircleMapper.deleteQwFriendCircleByIds(ids);
    }

    /**
     * 删除客户朋友圈信息
     * 
     * @param id 客户朋友圈主键
     * @return 结果
     */
    @Override
    public int deleteQwFriendCircleById(Long id)
    {
        return qwFriendCircleMapper.deleteQwFriendCircleById(id);
    }
}
