package com.fs.qw.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.fs.common.utils.DateUtils;
import com.fs.his.vo.OptionsVO;
import com.fs.qw.domain.QwInformation;
import com.fs.qw.mapper.QwInformationMapper;
import com.fs.qw.service.IQwInformationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 信息流管理Service业务层处理
 *
 * @author fs
 * @date 2024-11-11
 */
@Service
public class QwInformationServiceImpl implements IQwInformationService
{
    @Autowired
    private QwInformationMapper qwInformationMapper;

    /**
     * 查询信息流管理
     *
     * @param id 信息流管理主键
     * @return 信息流管理
     */
    @Override
    public QwInformation selectQwInformationById(Long id)
    {
        return qwInformationMapper.selectQwInformationById(id);
    }

    /**
     * 查询信息流管理列表
     *
     * @param qwInformation 信息流管理
     * @return 信息流管理
     */
    @Override
    public List<QwInformation> selectQwInformationList(QwInformation qwInformation)
    {
        return qwInformationMapper.selectQwInformationList(qwInformation);
    }

    /**
     * 新增信息流管理
     *
     * @param qwInformation 信息流管理
     * @return 结果
     */
    @Override
    public int insertQwInformation(QwInformation qwInformation)
    {
        qwInformation.setCreateTime(DateUtils.getNowDate());
        return qwInformationMapper.insertQwInformation(qwInformation);
    }

    /**
     * 修改信息流管理
     *
     * @param qwInformation 信息流管理
     * @return 结果
     */
    @Override
    public int updateQwInformation(QwInformation qwInformation)
    {
        qwInformation.setUpdateTime(DateUtils.getNowDate());
        return qwInformationMapper.updateQwInformation(qwInformation);
    }

    /**
     * 批量删除信息流管理
     *
     * @param ids 需要删除的信息流管理主键
     * @return 结果
     */
    @Override
    public int deleteQwInformationByIds(Long[] ids)
    {
        return qwInformationMapper.deleteQwInformationByIds(ids);
    }

    /**
     * 删除信息流管理信息
     *
     * @param id 信息流管理主键
     * @return 结果
     */
    @Override
    public int deleteQwInformationById(Long id)
    {
        return qwInformationMapper.deleteQwInformationById(id);
    }

    @Override
    public List<JSONObject> selectQwWayStatisticsCounts(Map<String, Object> map) {
        return qwInformationMapper.selectQwWayStatisticsCounts(map);
    }

    @Override
    public List<OptionsVO> selectQwInformationListOptionsVO() {

       return qwInformationMapper.selectQwInformationListOptionsVO();
    }
}
