package com.fs.qw.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwSession;
import com.fs.qw.mapper.QwSessionMapper;
import com.fs.qw.service.IQwSessionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 企微会话Service业务层处理
 *
 * @author fs
 * @date 2024-12-17
 */
@Service
public class QwSessionServiceImpl implements IQwSessionService
{
    @Autowired
    private QwSessionMapper qwSessionMapper;

    /**
     * 查询企微会话
     *
     * @param sessionId 企微会话主键
     * @return 企微会话
     */
    @Override
    public QwSession selectQwSessionBySessionId(Long sessionId)
    {
        return qwSessionMapper.selectQwSessionBySessionId(sessionId);
    }

    /**
     * 查询企微会话列表
     *
     * @param qwSession 企微会话
     * @return 企微会话
     */
    @Override
    public List<QwSession> selectQwSessionList(QwSession qwSession)
    {
        return qwSessionMapper.selectQwSessionList(qwSession);
    }

    /**
     * 新增企微会话
     *
     * @param qwSession 企微会话
     * @return 结果
     */
    @Override
    public int insertQwSession(QwSession qwSession)
    {
        qwSession.setCreateTime(DateUtils.getNowDate());
        return qwSessionMapper.insertQwSession(qwSession);
    }

    /**
     * 修改企微会话
     *
     * @param qwSession 企微会话
     * @return 结果
     */
    @Override
    public int updateQwSession(QwSession qwSession)
    {
//        qwSession.setUpdateTime(DateUtils.getNowDate());
        return qwSessionMapper.updateQwSession(qwSession);
    }

    /**
     * 批量删除企微会话
     *
     * @param sessionIds 需要删除的企微会话主键
     * @return 结果
     */
    @Override
    public int deleteQwSessionBySessionIds(Long[] sessionIds)
    {
        return qwSessionMapper.deleteQwSessionBySessionIds(sessionIds);
    }

    /**
     * 删除企微会话信息
     *
     * @param sessionId 企微会话主键
     * @return 结果
     */
    @Override
    public int deleteQwSessionBySessionId(Long sessionId)
    {
        return qwSessionMapper.deleteQwSessionBySessionId(sessionId);
    }
}
