package com.fs.qw.service.impl;

import com.fs.qw.domain.QwUserVideo;
import com.fs.qw.mapper.QwUserVideoMapper;
import com.fs.qw.param.QwUserVideoParam;
import com.fs.qw.service.IQwUserVideoService;
import com.fs.qw.vo.QwUserVideoVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 企业微信的视频号Service业务层处理
 *
 * @author fs
 * @date 2025-01-14
 */
@Service
@Slf4j
public class QwUserVideoServiceImpl implements IQwUserVideoService
{
    @Autowired
    private QwUserVideoMapper qwUserVideoMapper;

    /**
     * 查询企业微信的视频号
     *
     * @param id 企业微信的视频号主键
     * @return 企业微信的视频号
     */
    @Override
    public QwUserVideo selectQwUserVideoById(Long id)
    {
        return qwUserVideoMapper.selectQwUserVideoById(id);
    }

    /**
     * 查询企业微信的视频号列表
     *
     * @param qwUserVideo 企业微信的视频号
     * @return 企业微信的视频号
     */
    @Override
    public List<QwUserVideo> selectQwUserVideoList(QwUserVideo qwUserVideo)
    {
        return qwUserVideoMapper.selectQwUserVideoList(qwUserVideo);
    }

    @Override
    public List<QwUserVideoVO> selectQwUserVideoListVO(QwUserVideoParam param) {
        return qwUserVideoMapper.selectQwUserVideoListVO(param);
    }

    /**
     * 新增企业微信的视频号
     *
     * @param qwUserVideo 企业微信的视频号
     * @return 结果
     */
    @Override
    public int insertQwUserVideo(QwUserVideo qwUserVideo)
    {
        return qwUserVideoMapper.insertQwUserVideo(qwUserVideo);
    }

    /**
     * 修改企业微信的视频号
     *
     * @param qwUserVideo 企业微信的视频号
     * @return 结果
     */
    @Override
    public int updateQwUserVideo(QwUserVideo qwUserVideo)
    {
        return qwUserVideoMapper.updateQwUserVideo(qwUserVideo);
    }

    /**
     * 批量删除企业微信的视频号
     *
     * @param ids 需要删除的企业微信的视频号主键
     * @return 结果
     */
    @Override
    public int deleteQwUserVideoByIds(Long[] ids)
    {
        return qwUserVideoMapper.deleteQwUserVideoByIds(ids);
    }

    /**
     * 删除企业微信的视频号信息
     *
     * @param id 企业微信的视频号主键
     * @return 结果
     */
    @Override
    public int deleteQwUserVideoById(Long id)
    {
        return qwUserVideoMapper.deleteQwUserVideoById(id);
    }
}
