package com.fs.statis.mapper;

import com.fs.statis.domain.FsTempPeriodQuery;
import org.apache.ibatis.annotations.*;

import java.util.List;

/**
 * 临时期次查询Mapper接口
 */
@Mapper
public interface FsTempPeriodQueryMapper {

    /**
     * 根据ID查询临时期次信息
     *
     * @param id 主键ID
     * @return 临时期次信息
     */
    @Select("SELECT id, period_id AS periodId FROM fs_temp_period_query WHERE id = #{id}")
    FsTempPeriodQuery findById(Long id);

    /**
     * 新增临时期次信息
     *
     * @param fsTempPeriodQuery 临时期次信息
     * @return 影响行数
     */
    @Insert("INSERT INTO fs_temp_period_query(id, period_id) VALUES(#{id}, #{periodId})")
    int insert(FsTempPeriodQuery fsTempPeriodQuery);

    /**
     * 更新临时期次信息
     *
     * @param fsTempPeriodQuery 临时期次信息
     * @return 影响行数
     */
    @Update("UPDATE fs_temp_period_query SET period_id = #{periodId} WHERE id = #{id}")
    int update(FsTempPeriodQuery fsTempPeriodQuery);

    /**
     * 批量插入临时期次信息
     *
     * @param list 临时期次信息列表
     * @return 影响行数
     */
    @Insert("<script>" +
            "INSERT INTO fs_temp_period_query(period_id) VALUES " +
            "<foreach collection='list' item='item' index='index' separator=','>" +
            "(#{item})" +
            "</foreach>" +
            "</script>")
    int insertBatch(@Param("list") List<String> list);

    @Delete("truncate table fs_temp_period_query")
    void clear();

}
