package com.fs.statis.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.fs.common.utils.StringUtils;
import com.fs.company.cache.ICompanyUserCacheService;
import com.fs.company.domain.CompanyDept;
import com.fs.company.domain.CompanyUser;
import com.fs.company.mapper.CompanyDeptMapper;
import com.fs.company.mapper.CompanyUserMapper;
import com.fs.qw.cache.QwSopCacheService;
import com.fs.qw.cache.QwUserCacheService;
import com.fs.qw.domain.QwUser;
import com.fs.qw.mapper.QwExternalContactMapper;
import com.fs.qw.mapper.QwUserMapper;
import com.fs.sop.domain.QwSop;
import com.fs.sop.domain.QwSopLogs;
import com.fs.sop.domain.SopUserLogs;
import com.fs.sop.domain.SopUserLogsInfo;
import com.fs.sop.mapper.*;
import com.fs.statis.domain.*;
import com.fs.statis.dto.StatsWatchLogPageListDTO;
import com.fs.statis.mapper.FsStatisSalerWatchMapper;
import com.fs.statis.mapper.FsStatisTempFsuserMapper;
import com.fs.statis.mapper.FsStatisTempParamMapper;
import com.fs.statis.mapper.FsTempPeriodQueryMapper ;
import com.fs.statis.service.FsStatisSalerWatchService;
import com.github.pagehelper.PageHelper;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.concurrent.*;
import java.util.stream.Collectors;

/**
 * 销售观看统计服务实现类
 */
@Service("fsStatisSalerWatchService")
@Slf4j
public class FsStatisSalerWatchServiceImpl implements FsStatisSalerWatchService {

    private final FsStatisSalerWatchMapper fsStatisSalerWatchMapper;

    private final CompanyUserMapper companyUserMapper;

    private final QwUserMapper qwUserMapper;

    private final QwSopLogsMapper qwSopLogsMapper;



    private final SopUserLogsMapper sopUserLogsMapper;

    private final CompanyDeptMapper companyDeptMapper;

    private final ICompanyUserCacheService companyUserCacheService;

    @Autowired
    private QwUserCacheService qwUserCacheService;

    @Autowired
    private FsStatisTempParamMapper fsStatisTempParamMapper;
    @Autowired
    private FsStatisTempFsuserMapper fsStatisTempFsuserMapper;

    @Autowired
    private QwSopCacheService qwSopCacheService;

    @Autowired
    public FsStatisSalerWatchServiceImpl(FsStatisSalerWatchMapper fsStatisSalerWatchMapper,
                                         CompanyUserMapper companyUserMapper,
                                         QwUserMapper qwUserMapper,
                                         QwSopLogsMapper qwSopLogsMapper,
                                         SopUserLogsMapper sopUserLogsMapper,
                                         CompanyDeptMapper companyDeptMapper,
                                         ICompanyUserCacheService companyUserCacheService) {
        this.fsStatisSalerWatchMapper = fsStatisSalerWatchMapper;
        this.companyUserMapper = companyUserMapper;
        this.qwUserMapper = qwUserMapper;
        this.qwSopLogsMapper = qwSopLogsMapper;
        this.sopUserLogsMapper = sopUserLogsMapper;
        this.companyDeptMapper = companyDeptMapper;
        this.companyUserCacheService = companyUserCacheService;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public FsStatisSalerWatch getById(Integer id) {
        if (id == null) {
            return null;
        }
        return fsStatisSalerWatchMapper.findById(id);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public List<FsStatisSalerWatch> getAll() {
        return fsStatisSalerWatchMapper.findAll();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public FsStatisSalerWatch create(FsStatisSalerWatch fsStatisSalerWatch) {
        if (fsStatisSalerWatch == null) {
            return null;
        }
        fsStatisSalerWatch.setId(null);
        fsStatisSalerWatchMapper.insert(fsStatisSalerWatch);
        return fsStatisSalerWatch;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public FsStatisSalerWatch update(FsStatisSalerWatch fsStatisSalerWatch) {
        if (fsStatisSalerWatch == null || fsStatisSalerWatch.getId() == null) {
            return null;
        }
        int affectedRows = fsStatisSalerWatchMapper.update(fsStatisSalerWatch);
        if (affectedRows > 0) {
            return fsStatisSalerWatch;
        }
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean deleteById(Integer id) {
        if (id == null) {
            return false;
        }
        int affectedRows = fsStatisSalerWatchMapper.deleteById(id);
        return affectedRows > 0;
    }

    @Override
    public List<FsStatisSalerWatch> queryList(StatsWatchLogPageListDTO param) {
        if(StringUtils.isNull(param.getStartDate()) && StringUtils.isNull(param.getEndDate())) {
            return Collections.emptyList();
        }
        List<FsStatisSalerWatch> fsStatisSalerWatches = fsStatisSalerWatchMapper.queryList(param);
        for (FsStatisSalerWatch item : fsStatisSalerWatches) {
            if(item.getDeptId() != null) {
                CompanyDept companyDept = companyDeptMapper.selectCompanyDeptById(item.getDeptId());
                if(ObjectUtils.isNotNull(companyDept)) {
                    item.setDeptName(companyDept.getDeptName());
                }
            }
            if(item.getCompanyUserId() != null) {
                String companyUserName = companyUserCacheService.selectCompanyUserNameUserById(item.getCompanyUserId());
                if(StringUtils.isNotEmpty(companyUserName)){
                    item.setCompanyUserName(companyUserName);
                }
            }

        }
        return fsStatisSalerWatches;
    }

    @Override
    public List<FsStatisSalerWatch> queryPeriodList(StatsWatchLogPageListDTO param) {
        if(StringUtils.isNull(param.getStartDate()) && StringUtils.isNull(param.getEndDate())) {
            return Collections.emptyList();
        }
        List<FsStatisSalerWatch> fsStatisSalerWatches = fsStatisSalerWatchMapper.queryPeriodList(param);
        for (FsStatisSalerWatch item : fsStatisSalerWatches) {
            if(item.getDeptId() != null) {
                CompanyDept companyDept = companyDeptMapper.selectCompanyDeptById(item.getDeptId());
                if(ObjectUtils.isNotNull(companyDept)) {
                    item.setDeptName(companyDept.getDeptName());
                }
            }
            if(item.getCompanyUserId() != null) {
                String companyUserName = companyUserCacheService.selectCompanyUserNameUserById(item.getCompanyUserId());
                if(StringUtils.isNotEmpty(companyUserName)){
                    item.setCompanyUserName(companyUserName);
                }
            }

            if(item.getPeriodId() != null) {
                String qwSopLogNameBySopId = qwSopCacheService.getQwSopLogNameBySopId(item.getPeriodId());
                if(StringUtils.isNotEmpty(qwSopLogNameBySopId)) {
                    item.setPeriodName(qwSopLogNameBySopId);
                }
            }

            if(item.getSopId() != null) {
                String qwSopNameBySopId = qwSopCacheService.getQwSopNameBySopId(item.getSopId());
                if(StringUtils.isNotEmpty(qwSopNameBySopId)) {
                    item.setSopTaskName(qwSopNameBySopId);
                }
            }
        }
        return fsStatisSalerWatches;
    }

    @Override
    public List<FsStatisSalerWatch> queryTodayList(StatsWatchLogPageListDTO param) {
        if(StringUtils.isNull(param.getStartDate()) && StringUtils.isNull(param.getEndDate())) {
            return Collections.emptyList();
        }
        List<FsStatisSalerWatch> fsStatisSalerWatches = fsStatisSalerWatchMapper.queryTodayList(param);
        for (FsStatisSalerWatch item : fsStatisSalerWatches) {
            if(item.getDeptId() != null) {
                CompanyDept companyDept = companyDeptMapper.selectCompanyDeptById(item.getDeptId());
                if(ObjectUtils.isNotNull(companyDept)) {
                    item.setDeptName(companyDept.getDeptName());
                }
            }
            if(item.getCompanyUserId() != null) {
                String companyUserName = companyUserCacheService.selectCompanyUserNameUserById(item.getCompanyUserId());
                if(StringUtils.isNotEmpty(companyUserName)){
                    item.setCompanyUserName(companyUserName);
                }
            }

            if(item.getPeriodId() != null) {
                String periodName = qwSopLogsMapper.queryPeriodNameById(item.getPeriodId());
                if(StringUtils.isNotEmpty(periodName)) {
                    item.setPeriodName(periodName);
                }
            }

        }
        return fsStatisSalerWatches;
    }

    @Override
    public List<FsStatisSalerWatch> export(StatsWatchLogPageListDTO param) {
        if(StringUtils.isNull(param.getStartDate()) && StringUtils.isNull(param.getEndDate())) {
            return Collections.emptyList();
        }
        return fsStatisSalerWatchMapper.queryListExport(param);
    }

    @Override
    public List<FsStatisSopWatch> exportQueryPeriodList(StatsWatchLogPageListDTO param) {
        if(StringUtils.isNull(param.getStartDate()) && StringUtils.isNull(param.getEndDate())) {
            return Collections.emptyList();
        }
        List<FsStatisSopWatch> fsStatisSopWatches = fsStatisSalerWatchMapper.queryPeriodListExport(param);
        Map<String, QwSopLogs> stringQwSopLogsMap = qwSopLogsMapper.queryAllPeriod();

        for (FsStatisSopWatch item : fsStatisSopWatches) {
            if(item.getPeriodId() != null) {
                QwSopLogs qwSopLogs = stringQwSopLogsMap.get(item.getPeriodId());
                if(qwSopLogs != null) {
                    item.setPeriodName(qwSopLogs.getSopTitle());
                }
            } else {
                item.setPeriodName("空营期");
            }
        }
        return fsStatisSopWatches;
    }

    @Override
    public List<FsStatisEveryDayWatch> exportQueryEveryDayList(StatsWatchLogPageListDTO param) {
        if(StringUtils.isNull(param.getStartDate()) && StringUtils.isNull(param.getEndDate())) {
            return Collections.emptyList();
        }
        return fsStatisSalerWatchMapper.queryEveryDayListExport(param);
    }


    @Override
    public synchronized void writeData(String date) {

        // 统计销售看课情况
        // 获取前一天的时间
        List<CompanyUser> companyUserList = this.companyUserMapper.selectAllCompanyUserList();
        // 查询所有符合条件的 SOP 用户日志
        List<SopUserLogs> allSopUserLogs = sopUserLogsMapper.queryAllSopUserLogs();

        Map<String, List<SopUserLogs>> qwUserIdToIdsMap = allSopUserLogs.stream()
                .filter(Objects::nonNull)
                .filter(log -> log.getQwUserId() != null && log.getId() != null)
                .collect(Collectors.groupingBy(SopUserLogs::getQwUserId));

        qwUserCacheService.initCache();

        Map<Long, List<String>> qwUserIdMap = queryQwListMap();

        LocalDate previousDay = LocalDate.now().minusDays(1);
        if(date != null) {
            previousDay = LocalDate.parse(date, DateTimeFormatter.ofPattern("yyyy-MM-dd"));
        }

        List<FsStatisTempParam> list = new ArrayList<>();
        for (CompanyUser companyUser : companyUserList) {

            if(companyUser.getCompanyId() == null) {
                log.info("销售{} 对应公司id {} 为空！",companyUser.getUserId(),companyUser.getCompanyId());
                continue;
            }
            // 找到销售关联的 企微账号
            List<String> qwUserIdList = qwUserIdMap.get(companyUser.getUserId());
            if(CollectionUtils.isEmpty(qwUserIdList)){
                log.info("当前销售 {} 没有关联企微账号！",companyUser.getUserId());
                continue;
            }

            // 确定当前销售对应的sop任务的执行记录
            List<SopUserLogs> periodList = getPeriodListByQwUserIds(allSopUserLogs,qwUserIdToIdsMap,qwUserIdList);

            if(CollectionUtils.isEmpty(periodList)){
                log.info("当前销售 {} 没有相关的SOP营期！", companyUser.getUserId());
                continue;
            }


            for (SopUserLogs sopUserLogs : periodList) {

                String periodId = sopUserLogs.getId();
                String sopId = sopUserLogs.getSopId();
                String startTime = sopUserLogs.getStartTime();

                FsStatisTempParam param = new FsStatisTempParam();

                param.setCompanyUserId(companyUser.getUserId());
                param.setSopId(sopId);
                param.setThisDate(previousDay);
                param.setStartTime(startTime);
                String qwUserId = qwUserCacheService.getIdByQwUserIdAndCorpId(sopUserLogs.getQwUserId(), sopUserLogs.getCorpId());

                param.setQwUserId(qwUserId);
                param.setPeriodId(periodId);
                param.setDeptId(companyUser.getDeptId());
                list.add(param);
            }
        }

        // --------清空临时表----------
        fsStatisTempParamMapper.clearSop();
        fsStatisTempFsuserMapper.clear();
        fsStatisTempParamMapper.clear();

        // 删除之前的数据
        fsStatisSalerWatchMapper.deleteDateData(date);

        // -------开始计算-------------
        fsStatisTempParamMapper.batchSave(list);
        fsStatisTempParamMapper.batchSaveToSop(list);

        log.info("list 大小{}",list.size());

        // 根据临时表生成数据
        fsStatisSalerWatchMapper.generateData(date);

        // 写入企微重粉数和看课重粉数临时表
        List<FsStatisTempFsuser> tempData = fsStatisSalerWatchMapper.querySopRepeatData(date);
        fsStatisTempFsuserMapper.insertBatch(tempData);
        // 生成企微重粉数和看课重粉数
        fsStatisSalerWatchMapper.generateSopData(date);
        // 清空临时表
        fsStatisTempFsuserMapper.clear();
        fsStatisTempParamMapper.clear();
        fsStatisTempParamMapper.clearSop();
    }

    // 根据企微号查询SOP营期
    public List<SopUserLogs> getPeriodListByQwUserIds(List<SopUserLogs> allSopUserLogs,
                                                 Map<String, List<SopUserLogs>> qwUserIdToIdsMap
            ,List<String> qwUserIdList) {
        if (CollectionUtils.isEmpty(allSopUserLogs) || CollectionUtils.isEmpty(qwUserIdList)) {
            return new ArrayList<>();
        }

        return qwUserIdList.stream()
                .filter(Objects::nonNull)
                .map(qwUserIdToIdsMap::get)
                .filter(Objects::nonNull)
                .flatMap(List::stream)
                .collect(Collectors.toList());
    }

    private Map<Long,List<String>> queryQwListMap(){
        List<QwUser> qwUsers = qwUserMapper.selectQwUserAllList();
        if(CollectionUtils.isEmpty(qwUsers)){
            return Maps.newHashMap();
        }

        return qwUsers.stream()
                .filter(Objects::nonNull)
                .filter(user -> user.getCompanyUserId() != null && user.getQwUserId() != null)
                .collect(Collectors.groupingBy(
                        QwUser::getCompanyUserId,
                        Collectors.mapping(QwUser::getQwUserId, Collectors.toList())
                ));
    }

    private Map<String,List<Long>> queryQwIdMap(){
        List<QwUser> qwUsers = qwUserMapper.selectQwUserAllList();
        if(CollectionUtils.isEmpty(qwUsers)){
            return Maps.newHashMap();
        }

        return qwUsers.stream()
                .filter(Objects::nonNull)
                .filter(user -> user.getId() != null && user.getQwUserId() != null)
                .collect(Collectors.groupingBy(
                        QwUser::getQwUserId,
                        Collectors.mapping(QwUser::getId, Collectors.toList())
                ));

    }


    @Override
    public void writeDataToday() {
        LocalDate now = LocalDate.now();

        this.writeData(now.toString());
    }
}
