package com.fs.course.config;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.socket.server.standard.ServerEndpointExporter;
import org.springframework.web.socket.server.standard.ServletServerContainerFactoryBean;

@Configuration
public class WebSocketConfig {
    /**
     * 自动注册使用了@ServerEndpoint注解声明的Websocket endpoint
     *
     * @return
     */
    @Bean
    public ServerEndpointExporter serverEndpointExporter() {
        return new ServerEndpointExporter();
    }

    /**
     * 通信文本消息和二进制缓存区大小
     * 避免对接 第三方 报文过大时，Websocket 1009 错误
     *
     * @return
     */
    @Bean
    public ServletServerContainerFactoryBean createWebSocketContainer() {
        ServletServerContainerFactoryBean container = new ServletServerContainerFactoryBean();
        // 设置文本消息缓冲区大小
        container.setMaxTextMessageBufferSize(10240000);
        // 设置二进制消息缓冲区大小
        container.setMaxBinaryMessageBufferSize(10240000);
        // 设置最大会话空闲超时时间（单位：毫秒）
        container.setMaxSessionIdleTimeout(20 * 60000L); // 15分钟
        // 设置异步发送超时时间（单位：毫秒）
        container.setAsyncSendTimeout(300 * 1000L);
        return container;
    }

}
