package com.fs.course.controller;


import cn.hutool.json.JSONUtil;
import com.fs.course.annotation.Login;
import com.fs.common.annotation.RepeatSubmit;
import com.fs.common.core.domain.R;
import com.fs.common.utils.DateUtils;
import com.fs.common.utils.ServletUtils;
import com.fs.common.utils.StringUtils;
import com.fs.core.utils.OrderCodeUtils;
import com.fs.course.config.CourseConfig;
import com.fs.course.domain.*;
import com.fs.course.param.*;
import com.fs.course.service.*;
import com.fs.course.service.IFsUserCourseService;
import com.fs.course.service.impl.TencentCloudCosService;
import com.fs.course.vo.*;
import com.fs.his.service.IFsIntegralGoodsService;
import com.fs.his.vo.OptionsVO;
import com.fs.sop.domain.QwSop;
import com.fs.sop.service.IQwSopService;
import com.fs.system.service.ISysConfigService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.jsonwebtoken.Claims;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.Synchronized;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.spring.web.readers.operation.CachingOperationNameGenerator;

import javax.servlet.http.HttpServletRequest;
import java.util.*;

@Api("课堂接口")
@RestController
@RequestMapping(value="/app/course")
public class CourseController extends  AppBaseController{
    Logger logger= LoggerFactory.getLogger(getClass());
    @Autowired
    private IFsUserCourseService courseService;
    @Autowired
    private IFsUserCourseCategoryService courseCategoryService;

    @Autowired
    private IFsUserCourseVideoService courseVideoService;


    @Autowired
    private ISysConfigService configService;
    @Autowired
    private IFsCourseLinkService courseLinkService;

    @Autowired
    private IFsCourseQuestionBankService questionBankService;

    @Autowired
    private IFsCourseWatchLogService courseWatchLogService;

    @Autowired
    private IFsCourseWatchCommentService courseWatchCommentService;

    @Autowired
    private IFsIntegralGoodsService goodsService;

    @Autowired
    private IQwSopService qwSopService;


    @ApiOperation("h5课程简介")
    @GetMapping("/getH5CourseByVideoId")
    public R getCourseByVideoId(@RequestParam("videoId") Long videoId,HttpServletRequest request)
    {
        FsUserCourseVideoH5VO course = courseService.selectFsUserCourseVideoH5VOByVideoId(videoId);
        return R.ok().put("data",course);
    }

    @Login
    @ApiOperation("h5课程详情加问答")
    @GetMapping("/getH5CourseVideoDetails")
    public R getCourseVideoDetails(FsUserCourseVideoFinishUParam param)
    {
        param.setUserId(Long.parseLong(getUserId()));
        String json = configService.selectConfigByKey("course.config");
        CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);
        FsUserCourseVideoH5DVO course = courseService.selectFsUserCourseVideoH5DVOByVideoId(param.getVideoId());
        List<FsUserCourseVideoQuestionVO> questionVOList = new ArrayList<>();
        if (StringUtils.isNotEmpty(course.getQuestionBankId())){
            String[] questionIds = course.getQuestionBankId().split(",");
            for (String questionId : questionIds){
                FsUserCourseVideoQuestionVO vo = new FsUserCourseVideoQuestionVO();
                FsCourseQuestionBank questionBank = questionBankService.selectFsCourseQuestionBankById(Long.parseLong(questionId));
                if (questionBank!=null&&questionBank.getStatus()!=0){
                    BeanUtils.copyProperties(questionBank,vo);
                    questionVOList.add(vo);
                }
            }
        }
        Long duration = 0L;
        long tipsTime = 0L;
        int isFinish = 0;
        if (param.getLinkType()!=null&&param.getLinkType()==1){
            return R.ok().put("course",course).put("questions",questionVOList).put("config",config).put("playDuration",duration).put("tipsTime",tipsTime);
        }

        if (param.getIsRoom()!=null&&param.getIsRoom()==1&&param.getQwExternalId()==null){
            return R.ok().put("course",course).put("questions",questionVOList).put("config",config).put("playDuration",duration).put("tipsTime",tipsTime);
        }
        // 从Redis中获取观看时长
        String redisKey = "h5user:watch:duration:" + param.getQwUserId()+ ":" + param.getQwExternalId() + ":" + param.getVideoId();
        String durationStr = redisCache.getCacheObject(redisKey);
        FsCourseWatchLog log = courseWatchLogService.getWatchCourseVideo(param.getUserId(),param.getVideoId(),param.getQwUserId(),param.getQwExternalId());
        if (log==null){
            return R.error("记录不存在，请联系客服!");
        }
        //redis取不到查库
        if (durationStr != null) {
            duration = Long.parseLong(durationStr);
        }else {
            duration = log.getDuration();
        }

        if (course.getDuration()!=null){
            tipsTime = course.getDuration()/2;
        }
        //判断是否完课
        if (log.getLogType()==2){
            isFinish=1;
        }

        //将视频时长也存到redis
        String videoRedisKey = "h5user:video:duration:" + param.getVideoId();
        Long videoDuration = redisCache.getCacheObject(videoRedisKey);
        if (videoDuration==null){

            redisCache.setCacheObject(videoRedisKey,course.getDuration());
        }
        // 返回是否开启评论/弹幕。优先获取sop任务配置的是否开启评论/弹幕，如果没有配置就取总后台的配置；
        QwSop qwSop = qwSopService.selectQwSopById(log.getSopId());
        if(qwSop != null && qwSop.getOpenCommentStatus() != null) {
            config.setOpenCommentStatus(qwSop.getOpenCommentStatus());
        }

        return R.ok().put("course",course).put("questions",questionVOList).put("config",config).put("playDuration",duration).put("tipsTime",tipsTime).put("isFinish",isFinish);
    }

    @ApiOperation("答题")
    @PostMapping("/courseAnswer")
    @Login
    public R courseAnswer(@RequestBody FsCourseQuestionAnswerUParam param)
    {
        logger.info("zyp \n【答题】：{}",param.getQuestions());
        if (param.getDuration()==null){
            logger.info("zyp \n【未识别到时长】：{}",param.getUserId());
        }
        param.setUserId(Long.parseLong(getUserId()));
        return questionBankService.courseAnswer(param,false);
    }


    @Login
    @ApiOperation("发放奖励")
    @PostMapping("/sendReward")
    @RepeatSubmit
    public R sendReward(@RequestBody FsCourseSendRewardUParam param)
    {
        param.setUserId(Long.parseLong(getUserId()));
        logger.info("zyp \n【发放奖励】：{}",param);
        return courseVideoService.sendReward(param);
    }

    @ApiOperation("获取真实链接")
    @GetMapping("/getRealLink")
    public R getRealLink(@RequestParam("sortLink")String link)
    {
        return courseLinkService.getRealLink(link);
    }

    @Login
    @ApiOperation("更新看课时长")
    @PostMapping("/updateWatchDuration")
    public R updateWatchDuration(@RequestBody FsUserCourseVideoFinishUParam param)
    {
        param.setUserId(Long.parseLong(getUserId()));
        return courseVideoService.updateWatchDuration(param);
    }

    @Login
    @ApiOperation("每十分钟获取积分")
    @PostMapping("/getIntegralByH5Video")
    public R getIntegralByH5Video(@RequestBody FsUserCourseVideoFinishUParam param)
    {
        param.setUserId(Long.parseLong(getUserId()));
        return courseVideoService.getIntegralByH5Video(param);
    }

    /**
     * 是否添加客服
     */
    @Login
    @ApiOperation("是否添加客服")
    @PostMapping("/isAddKf")
    public R isAddKf(@RequestBody FsUserCourseVideoAddKfUParam param) {
        Long userId = Long.parseLong(getUserId());
        param.setUserId(userId);
        return courseVideoService.isAddKf(param);
    }

    @Login
    @ApiOperation("获取缓冲流量")
    @PostMapping("/getInternetTraffic")
    public R getInternetTraffic(@RequestBody FsUserCourseVideoFinishUParam param) {
        Long userId = Long.parseLong(getUserId());
        param.setUserId(userId);
        return courseVideoService.getInternetTraffic(param);
    }


//    @Login
//    @ApiOperation("H5看课绑定手机号")
//    @PostMapping("/bindUserPhone")
//    public R bindUserPhone(@RequestBody FsCourseH5PhoneParam param) {
//        Long userId = Long.parseLong(getUserId());
//        param.setUserId(userId);
//        return courseVideoService.bindUserPhone(param);
//    }

    @GetMapping("/genOrderSn")
    public R genOrderSn() {
        String orderCode = OrderCodeUtils.getOrderSn();
        System.out.println(orderCode);
        redisCache.setCacheObject("orderCode"+orderCode,orderCode);
        return R.ok(orderCode);
    }


    @Login
    @PostMapping("/getErrMsg")
    public void getErrMsg(@RequestParam("msg") String msg) {
        Long userId = Long.parseLong(getUserId());
        logger.error("zyp \n【看课中途报错】：{}","userId:"+userId+msg);
    }


    @Login
    @ApiOperation("获取积分奖励信息")
    @GetMapping("/getCourseIntegralGoods")
    public R getCourseIntegralGoods() {
        return goodsService.getCourseIntegralGoods(Long.parseLong(getUserId()));
    }


    @Autowired
    TencentCloudCosService tencentCloudCosService;
    @Autowired
    IFsCourseLinkService linkService;

    @GetMapping("/test1")
    public void test1() {
        linkService.updateLinks();
    }


    @GetMapping("/test2")
    public void test2() {

//        courseVideoService.updateVideoUrl();
    }

    @Login
    @ApiOperation("保存评论数据")
    @PostMapping("/saveMsg")
    public R saveMsg(@RequestBody FsCourseWatchCommentSaveParam param)
    {
        param.setUserId(Long.parseLong(getUserId()));
        return courseWatchCommentService.saveH5CourseWatchComment(param);
    }

    @Login
    @ApiOperation("撤销评论")
    @PutMapping("/revokeMsg")
    public R revokeMsg(@ApiParam(value = "评论id", required = true) @RequestParam Long commentId)
    {
        return courseWatchCommentService.revokeH5CourseWatchComment(commentId);
    }

    @ApiOperation("获取历史评论数据")
    @GetMapping("/getComments")
    public R getCourseWatchComments(FsCourseWatchCommentListParam param)
    {
        //获取配置信息中需要查询的数据条数
        String json = configService.selectConfigByKey("course.config");
        CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);
        param.setListNum(config.getViewCommentNum() != null &&  config.getViewCommentNum() != 0 ? config.getViewCommentNum() : 200);

        PageHelper.startPage(param.getPageNum(), param.getPageSize());
        List<FsCourseWatchCommentVO> list = courseWatchCommentService.selectH5CourseWatchComments(param);
        PageInfo<FsCourseWatchCommentVO> pageInfo = new PageInfo<>(list);
        return R.ok().put("data", pageInfo);
    }


    /**
     * 校验是否可以答题
     *
     * @param param
     * @return
     */
    @PostMapping("/isAllowAnswer")
    public R isAllowAnswer(@RequestBody FsUserCourseVideoFinishUParam param) {
        return courseVideoService.isAllowAnswer(param);
    }

}
