package com.fs.framework.service;


import com.fs.common.enums.UserStatus;
import com.fs.common.exception.CustomException;
import com.fs.common.utils.StringUtils;
import com.fs.company.domain.Company;
import com.fs.company.domain.CompanyUser;
import com.fs.company.service.ICompanyService;
import com.fs.company.service.ICompanyUserService;
import com.fs.framework.security.LoginCompanyUser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

/**
 * 用户验证处理
 *

 */
@Service
public class UserDetailsServiceImpl implements UserDetailsService
{
    private static final Logger log = LoggerFactory.getLogger(UserDetailsServiceImpl.class);

    @Autowired
    private ICompanyUserService userService;

    @Autowired
    private CompanyPermissionService permissionService;

    @Autowired
    private ICompanyService companyService;




    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException
    {


        CompanyUser user = userService.selectUserByUserName(username);
        if (StringUtils.isNull(user))
        {
            log.info("登录用户：{} 不存在.", username);
            throw new UsernameNotFoundException("登录用户：" + username + " 不存在");
        }
        Company company=companyService.selectCompanyById(user.getCompanyId()) ;
        if(company==null||company.getStatus()==0||company.getIsDel()==1){
            throw new CustomException("此用户所属公司不存在或已停用");
        }
        if (UserStatus.DELETED.getCode().equals(user.getDelFlag()))
        {
            log.info("登录用户：{} 已被删除.", username);
            throw new CustomException("对不起，您的账号：" + username + " 已被删除");
        }
        else if (UserStatus.DISABLE.getCode().equals(user.getStatus()))
        {
            log.info("登录用户：{} 已被停用.", username);
            throw new CustomException("对不起，您的账号：" + username + " 已停用");
        }

        return createLoginUser(user);
    }

    public UserDetails createLoginUser(CompanyUser user)
    {
        return new LoginCompanyUser(user, permissionService.getMenuPermission(user),companyService.selectCompanyById(user.getCompanyId()));
    }
}
